"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseStringObject = exports.getObjectData = exports.ObjectQuoteRegex = void 0;
const StringObject_js_1 = __importDefault(require("../structs/StringObject.js"));
const stringParser_js_1 = require("./stringParser.js");
const transpilerHelpers_js_1 = require("../../util/transpilerHelpers.js");
exports.ObjectQuoteRegex = /".*?"/g;
function getObjectData(stringObject, currentObj) {
    let i = 0, text = "";
    while (i < stringObject.length) {
        const char = stringObject[i];
        if (char === "{" || char === "[") {
            const newObj = new StringObject_js_1.default(char, currentObj);
            currentObj.addValue(`#StringObject_${newObj.name}#`);
            currentObj = newObj;
        }
        else if (char === "}" || char === "]") {
            currentObj.addEnd(char);
            if (text.trim() !== "") {
                let t = (0, transpilerHelpers_js_1.parseData)(text.trim());
                if (typeof t === "string") {
                    if (t.trim().startsWith("'") ||
                        t.trim().startsWith("\"") ||
                        t.trim().startsWith("`")) {
                        t = t.trim().slice(1, t.trim().length - 1);
                        t = (0, stringParser_js_1.parseString)(t);
                    }
                    else if (t.includes("#FUNCTION_START#")) {
                        if (t
                            .replaceAll(/#FUNCTION_START#(.+?)#FUNCTION_END#/g, "")
                            .trim() !== "") {
                            t = (0, stringParser_js_1.parseString)(t);
                        }
                    }
                    else
                        t = (0, stringParser_js_1.parseString)(t);
                }
                currentObj.addValue(t);
                text = "";
            }
            currentObj.parent?.pushChild(currentObj);
            currentObj = currentObj.parent;
        }
        else if (char === ":") {
            currentObj.addKey(text.trim());
            text = "";
        }
        else if (char === ",") {
            if (currentObj.start === "[") {
                let t = (0, transpilerHelpers_js_1.parseData)(text.trim());
                if (typeof t === "string") {
                    if (t.trim().startsWith("'") ||
                        t.trim().startsWith("\"") ||
                        t.trim().startsWith("`")) {
                        t = t.trim().slice(1, t.trim().length - 1);
                        t = (0, stringParser_js_1.parseString)(t);
                    }
                    else if (t.includes("#FUNCTION_START#")) {
                        if (t
                            .replaceAll(/#FUNCTION_START#(.+?)#FUNCTION_END#/g, "")
                            .trim() !== "") {
                            t = (0, stringParser_js_1.parseString)(t);
                        }
                    }
                    else
                        t = (0, stringParser_js_1.parseString)(t);
                }
                currentObj.addValue(t);
            }
            else {
                let t = (0, transpilerHelpers_js_1.parseData)(text.trim());
                if (typeof t === "string") {
                    if (t.trim().startsWith("'") ||
                        t.trim().startsWith("\"") ||
                        t.trim().startsWith("`")) {
                        t = t.trim().slice(1, t.trim().length - 1);
                        t = (0, stringParser_js_1.parseString)(t);
                    }
                    else if (t.includes("#FUNCTION_START#")) {
                        if (t
                            .replaceAll(/#FUNCTION_START#(.+?)#FUNCTION_END#/g, "")
                            .trim() !== "") {
                            t = (0, stringParser_js_1.parseString)(t);
                        }
                    }
                    else
                        t = (0, stringParser_js_1.parseString)(t);
                }
                currentObj.addValue(t);
            }
            text = "";
        }
        else {
            text += char;
        }
        i++;
    }
    if (text.trim() !== "") {
        let t = (0, transpilerHelpers_js_1.parseData)(text.trim());
        if (typeof t === "string") {
            if (t.trim().startsWith("'") ||
                t.trim().startsWith("\"") ||
                t.trim().startsWith("`")) {
                t = t.trim().slice(1, t.trim().length - 1);
                t = (0, stringParser_js_1.parseString)(t);
            }
            else if (t.includes("#FUNCTION_START#")) {
                if (t
                    .replaceAll(/#FUNCTION_START#(.+?)#FUNCTION_END#/g, "")
                    .trim() !== "") {
                    t = (0, stringParser_js_1.parseString)(t);
                }
            }
            else
                t = (0, stringParser_js_1.parseString)(t);
        }
        currentObj.addValue(t);
    }
    return currentObj;
}
exports.getObjectData = getObjectData;
function parseStringObject(stringObject, currentObj) {
    const quotes = stringObject.match(exports.ObjectQuoteRegex);
    if (quotes) {
        quotes.forEach((x) => {
            const newx = x
                .replaceAll(":", "#OBJECT_SEPARATER#")
                .replaceAll("{", "#OBJECT_STARTER#")
                .replaceAll("}", "#OBJECT_ENDER#")
                .replaceAll("[", "#ARRAY_STARTER#")
                .replaceAll("]", "#ARRAY_ENDER#")
                .replaceAll(",", "#ARRAY_SEPARATOR#");
            stringObject = stringObject.replace(x, newx);
        });
    }
    return getObjectData(stringObject.slice(1, stringObject.length - 1), currentObj);
}
exports.parseStringObject = parseStringObject;
//# sourceMappingURL=objectParser.js.map