"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Transpiler = void 0;
const index_js_1 = __importDefault(require("../functions/index.js"));
const uglify_js_1 = require("uglify-js");
const transpilerHelpers_js_1 = require("../util/transpilerHelpers.js");
const error_js_1 = require("./error.js");
const mathParser_js_1 = __importDefault(require("./parsers/mathParser.js"));
const Scope_js_1 = __importDefault(require("./structs/Scope.js"));
function Transpiler(code, options) {
    const { scopeData, sendMessage, minify: uglify, customFunctions } = options;
    const functions = { ...index_js_1.default, ...customFunctions };
    const functionNames = Object.keys(functions);
    const flist = (0, transpilerHelpers_js_1.getFunctionList)(code, functionNames);
    flist.forEach((x) => {
        const reg = new RegExp(`${x.replace("$", "\\$")}`, "gi");
        code = (0, transpilerHelpers_js_1.parseResult)(code);
        code = code.replace(reg, x);
    });
    const tempcode = `$EXECUTEMAINCODEFUNCTION[
        ${code}
    ]`;
    const FData = (0, transpilerHelpers_js_1.getFunctionData)(tempcode, "$EXECUTEMAINCODEFUNCTION", flist);
    const globalScope = new Scope_js_1.default(scopeData?.name ?? "global", options.client, undefined, code);
    globalScope.addVariables(scopeData?.variables ?? []);
    globalScope.addEmbeds(scopeData?.embeds ?? []);
    globalScope.env.push(...(scopeData?.env ?? []));
    globalScope.objects = { ...globalScope.objects, ...scopeData?.objects };
    globalScope.embededJS = scopeData?.embedJs ?? [];
    globalScope.sendFunction =
        scopeData?.sendFunction ?? globalScope.sendFunction;
    globalScope.useChannel = scopeData?.useChannel;
    const res = (0, transpilerHelpers_js_1.ExecuteData)((0, transpilerHelpers_js_1.parseResult)(code), FData.funcs, [globalScope], options.reverse ?? false);
    if (res.scope[0].sendData.content.trim() !== "") {
        const scope = res.scope[0];
        scope.hasSendData = true;
        scope.rest = scope.rest.replace(scope.sendData.content.trim(), "");
        res.scope[0] = scope;
    }
    res.scope[0].updateEmbedJs();
    let str = res.scope[0].getFunction(sendMessage);
    str = (0, mathParser_js_1.default)(str);
    // eslint-disable-next-line @typescript-eslint/ban-types
    const functionString = uglify ? (0, uglify_js_1.minify)(str) : str;
    if (uglify && functionString.error) {
        throw new error_js_1.TranspilerError(`code:${str} 
<------------------------------------------------------->
      Failed To Transpile Code with error ${functionString.error}`);
    }
    let func;
    if (options.parsedStringOnly)
        return {
            code: uglify
                ? functionString.code
                : functionString,
            func: async () => {
                return void 0;
            },
            scope: res.scope,
        };
    try {
        const strr = uglify
            ? functionString.code
            : functionString;
        func = eval(`const f = ${strr}; f`);
    }
    catch (e) {
        throw new error_js_1.TranspilerError(e + "\n\n\n" + str);
    }
    return { func, ...res };
}
exports.Transpiler = Transpiler;
//# sourceMappingURL=transpiler.js.map