"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.interactionCreate = exports.onInteraction = void 0;
const zeneth_1 = require("zeneth");
const DapiHelper_js_1 = require("../util/DapiHelper.js");
const enums_js_1 = require("../typings/enums.js");
function onInteraction(client) {
    client.client.on(zeneth_1.GatewayEventNames.InteractionCreate, async (interaction) => {
        await interactionCreate(interaction, client);
    });
}
exports.onInteraction = onInteraction;
async function interactionCreate(interaction, client) {
    const cmdName = getCommandName(interaction);
    if (!cmdName)
        return;
    await client.managers.commands
        .exec({
        type: "interaction",
        data: {
            interaction,
            client: client.client,
            bot: client,
            message: interaction.message,
            channel: (interaction.channel ??
                client.cache?.channels?.get(interaction.channelId) ??
                (0, DapiHelper_js_1.isAutoFetchDataEnabled)("channel", client))
                ? await client.client.getChannel(interaction.channelId)
                : { id: interaction.channelId, fetched: false },
            guild: (client.cache?.guilds?.get(interaction.guildId) ??
                (0, DapiHelper_js_1.isAutoFetchDataEnabled)("guild", client))
                ? await client.client.getGuild(interaction.guildId)
                : { id: interaction.guildId, fetched: false },
            author: interaction.user,
            member: interaction.member,
        },
        filter: (cmd) => cmd.name === cmdName,
    })
        .catch((e) => {
        if (e.component && !e.success)
            return;
        else
            client.emit(enums_js_1.AoiClientEvents.Error, e);
    });
}
exports.interactionCreate = interactionCreate;
function getCommandName(interaction) {
    switch (interaction.type) {
        case zeneth_1.InteractionTypes.ApplicationCommand:
            return interaction.data.name;
        case zeneth_1.InteractionTypes.MessageComponent:
            return interaction.customId;
        case zeneth_1.InteractionTypes.ApplicationCommandAutocomplete:
            return interaction.data.name;
        default:
            return undefined;
    }
}
//# sourceMappingURL=interactionCreate.js.map