"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.messageCreate = exports.onMessage = void 0;
const zeneth_1 = require("zeneth");
const DapiHelper_js_1 = require("../util/DapiHelper.js");
const enums_js_1 = require("../typings/enums.js");
function onMessage(client) {
    client.client.on(zeneth_1.GatewayEventNames.MessageCreate, async (message) => {
        await messageCreate(message, client);
    });
}
exports.onMessage = onMessage;
async function messageCreate(message, client) {
    let prefix;
    if (client.options.prefixes instanceof Array)
        prefix = client.options.prefixes.find((p) => message.content.startsWith(p));
    else
        prefix = client.options.prefixes;
    if (!prefix)
        return;
    if (!message.content.startsWith(prefix))
        return;
    const args = message.content.slice(prefix.length).trim().split(/ +/);
    const cmd = args.shift()?.toLowerCase();
    if (!cmd)
        return;
    await client.managers.commands
        .exec({
        type: "basic",
        filter: (x) => x.name === cmd || (x.aliases?.includes(cmd) ?? false),
        data: {
            message,
            channel: client.cache?.channels?.get(message.channelId) ??
                (0, DapiHelper_js_1.isAutoFetchDataEnabled)("channel", client)
                ? await client.client.getChannel(message.channelId)
                : { id: message.channelId, fetched: false },
            guild: (client.cache?.guilds?.get(message.guildId) ??
                (0, DapiHelper_js_1.isAutoFetchDataEnabled)("guild", client))
                ? await client.client.getGuild(message.guildId)
                : { id: message.guildId, fetched: false },
            author: message.author,
            client: client.client,
            args,
            bot: client,
            member: message.member,
        },
    })
        .catch((e) => {
        if (e.component && !e.success)
            return;
        else
            client.emit(enums_js_1.AoiClientEvents.Error, e);
    });
}
exports.messageCreate = messageCreate;
//# sourceMappingURL=messageCreate.js.map