"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.$interactionUpdate = void 0;
const index_js_1 = require("../../../index.js");
const Scope_js_1 = __importDefault(require("../../../core/structs/Scope.js"));
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$interactionUpdate = {
    name: "$interactionUpdate",
    brackets: true,
    optional: true,
    type: "scope",
    fields: [
        {
            name: "msg",
            type: "string",
            description: "The message to send",
            required: true,
        },
    ],
    description: "updates the original message of the interaction (only for message components)",
    default: ["void"],
    returns: "void",
    version: "7.0.0",
    example: `
        $interactionUpdate[hello world] // updates the original message with "hello world"

        $interactionUpdate[
            $title[hello world]
            $description[hello world]
        ] // updates the original message with an embed
    `,
    code: (data, scope) => {
        const currentScope = scope.at(-1);
        const funcs = [
            ...Object.keys(index_js_1.functions),
            ...currentScope.client.managers.functions.functions.K(),
        ];
        //code here
        const msg = data.inside;
        if (!msg &&
            (currentScope?.name.startsWith("$try") ||
                currentScope?.name.startsWith("$catch")))
            throw new index_js_1.TranspilerError(`${data.name} requires a message or content`);
        let msgExecute;
        const msgFunctionList = (0, transpilerHelpers_js_1.getFunctionList)(msg, funcs);
        const hash = Math.floor(Math.random() * 1000000);
        const newscope = new Scope_js_1.default(`${data.name}_${hash}`, currentScope.client, currentScope.name, (0, transpilerHelpers_js_1.parseResult)(msg), false);
        if (msgFunctionList.length) {
            msgExecute = (0, index_js_1.Transpiler)(msg, {
                client: currentScope.client,
                customFunctions: currentScope.client.managers.functions.functions.toJSON(),
                sendMessage: false,
                scopeData: {
                    variables: currentScope.variables,
                    embeds: currentScope.embeds,
                    name: newscope.name,
                    objects: currentScope.objects,
                },
            });
            newscope.functions = msgExecute.scope[0].functions + "\n";
            newscope.packages = msgExecute.scope[0].packages + "\n";
            newscope.setters = msgExecute.scope[0].setters + "\n";
            newscope.rest = msgExecute.scope[0].rest + "\n";
            newscope.sendData = msgExecute.scope[0].sendData;
            newscope.embeds = msgExecute.scope[0].embeds;
            newscope.components = msgExecute.scope[0].components;
            newscope.files = msgExecute.scope[0].files;
            newscope.stickers = msgExecute.scope[0].stickers;
            newscope.variables = msgExecute.scope[0].variables;
        }
        const res = (0, transpilerHelpers_js_1.escapeResult)(`await __$DISCORD_DATA$__.client.createInteractionResponse(__$DISCORD_DATA$__.interaction.id, __$DISCORD_DATA$__.interaction.token, 7, ${newscope.toString(false)});`);
        currentScope.update(res, data);
        return {
            code: res,
            scope,
        };
    },
};
//# sourceMappingURL=$interactionUpdate.js.map