"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$description = void 0;
const stringParser_js_1 = require("../../../core/parsers/stringParser.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$description = {
    name: "$description",
    brackets: true,
    optional: false,
    type: "setter",
    fields: [
        {
            name: "index or description",
            type: "string | number",
            description: "The index of the embed to set the description of",
            required: true,
        },
        {
            name: "description",
            type: "string",
            description: "The description to set",
            required: false,
        },
    ],
    description: "Sets the description of an embed at the specified index",
    default: ["text", ""],
    returns: "void",
    version: "7.0.0",
    example: `
        $description[hello world] // sets the description of the first embed to "hello world"

        $description[2;hello world] // sets the description of the second embed to "hello world"
    `,
    code: (data, scope) => {
        const currentScope = scope.at(-1);
        //code here
        const [indexOrDescription, ...description] = data.splits;
        const parsedDescription = description.join(";");
        let actualDescription;
        let index = 0;
        if (!parsedDescription)
            actualDescription = indexOrDescription;
        else if (parsedDescription && isNaN(Number(indexOrDescription)))
            actualDescription = indexOrDescription + ";" + parsedDescription;
        else {
            actualDescription = parsedDescription;
            index = Number(indexOrDescription) - 1;
        }
        let embed = currentScope.embeds[index];
        if (!embed) {
            embed = {
                fields: [],
            };
            currentScope.setters += (0, transpilerHelpers_js_1.escapeResult)(`${(0, transpilerHelpers_js_1.escapeVars)(currentScope.name + "_embeds")}[${index}] = { fields: [] };`);
        }
        embed.description = actualDescription;
        currentScope.embeds[index] = embed;
        const res = (0, transpilerHelpers_js_1.escapeResult)(`${(0, transpilerHelpers_js_1.escapeVars)(currentScope.name + "_embeds")}[${index}].description = ${(0, stringParser_js_1.parseString)(actualDescription)};`);
        currentScope.update(res, data);
        return {
            code: res,
            scope,
        };
    },
};
//# sourceMappingURL=$description.js.map