"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$arrayAt = void 0;
const error_js_1 = require("../../../core/error.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$arrayAt = {
    name: "$arrayAt",
    brackets: true,
    optional: false,
    type: "getter",
    fields: [
        {
            name: "name",
            type: "string",
            description: "The name of the array",
            required: true,
        },
        {
            name: "index",
            type: "number",
            description: "The index of the array",
            required: true,
        },
    ],
    description: "returns the value of the array at the specified index",
    default: ["void", "void"],
    returns: "any",
    version: "7.0.0",
    example: `
        $arrayCreate[myArray;hello;world;nya]
        $arrayAt[myArray;1] // returns "hello"
        $arrayAt[myArray;2] // returns "world"
        $arrayAt[myArray;-1] // returns "nya"
    `,
    code: (data, scope) => {
        const [name, index] = data.splits;
        const currentScope = scope[scope.length - 1];
        if (!currentScope.variables.includes(name) &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_"))
            throw new error_js_1.TranspilerError(`${data.name}: Variable ${name} doesn't exist`);
        const parsedIndex = (Number(index) < 0 ? Number(index) : Number(index) - 1);
        if (isNaN(parsedIndex) &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_"))
            throw new error_js_1.TranspilerError(`${data.name}: Index must be a number`);
        const res = (0, transpilerHelpers_js_1.escapeResult)(`${(0, transpilerHelpers_js_1.escapeVars)(name)}?.at(${parsedIndex})`);
        currentScope.update(res, data);
        return {
            code: res,
            scope,
        };
    },
};
//# sourceMappingURL=$arrayAt.js.map