"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$arrayConcat = void 0;
const error_js_1 = require("../../../core/error.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$arrayConcat = {
    name: "$arrayConcat",
    brackets: true,
    optional: false,
    type: "setter",
    fields: [
        {
            name: "name",
            type: "string",
            description: "The name of the array",
            required: true,
        },
        {
            name: "values",
            type: "string[]",
            description: "The arrays to concatenate",
            required: true,
        },
    ],
    description: "concatenates the specified values to the array",
    default: ["void", "void"],
    returns: "void",
    version: "7.0.0",
    example: `
        $arrayCreate[myArray;hello;world]
        $arrayCreate[myNextArray;nya]

        $arrayConcat[myArray;myNextArray] // myArray is now ["hello", "world", "nya"]
    `,
    code: (data, scope) => {
        const [name, ...values] = data.splits;
        const currentScope = scope[scope.length - 1];
        if (currentScope.objects[name] &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_"))
            throw new error_js_1.TranspilerError(`${data.name}: Variable ${name} already exists`);
        if (!currentScope.variables.every((x) => values.includes(x)) &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_"))
            throw new error_js_1.TranspilerError(`${data.name}: array ${values
                .filter((x) => !currentScope.variables.includes(x))
                .join(", ")} do(es) not exist`);
        currentScope.variables.push(name);
        const parsedValues = values.map((v) => (0, transpilerHelpers_js_1.escapeVars)(v));
        const res = (0, transpilerHelpers_js_1.escapeResult)(`const ${(0, transpilerHelpers_js_1.escapeVars)(name)} = [...${parsedValues.join(", ...")}];`);
        currentScope.update(res, data);
        return {
            code: "",
            scope,
        };
    },
};
//# sourceMappingURL=$arrayConcat.js.map