"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$arrayCreate = void 0;
const error_js_1 = require("../../../core/error.js");
const index_js_1 = require("../../../index.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$arrayCreate = {
    name: "$arrayCreate",
    brackets: true,
    optional: false,
    type: "setter",
    fields: [
        {
            name: "name",
            type: "string",
            description: "The name of the array",
            required: true,
        },
        {
            name: "values",
            type: "unknown",
            description: "The values to create the array with",
            required: true,
        },
    ],
    description: "creates an array with the specified values",
    default: ["void", "void"],
    returns: "void",
    version: "7.0.0",
    example: `
        $arrayCreate[myArray;hello;world;nya]
        $arrayCreate[myNextArray;1;2;3]
    `,
    code: (data, scope) => {
        const [name, ...values] = data.splits;
        const currentScope = scope[scope.length - 1];
        if (currentScope.objects[name] &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_"))
            throw new error_js_1.TranspilerError(`${data.name}: Variable ${name} already exists`);
        const parsedValues = values.map((v) => (0, transpilerHelpers_js_1.parseData)(v));
        const currentObj = new index_js_1.StringObject("[");
        currentObj.addEnd("]");
        const array = (0, index_js_1.parseStringObject)(`[${parsedValues.join(" , ")}]`, currentObj);
        currentScope.objects[name] = array;
        currentScope.variables.push(name);
        const res = (0, transpilerHelpers_js_1.escapeResult)(`const ${(0, transpilerHelpers_js_1.escapeVars)(name)} = ${array.solve()};`);
        currentScope.update(res, data);
        return {
            code: "",
            scope,
        };
    },
};
//# sourceMappingURL=$arrayCreate.js.map