"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$arrayForEach = void 0;
const error_js_1 = require("../../../core/error.js");
const index_js_1 = require("../../../index.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$arrayForEach = {
    name: "$arrayForEach",
    brackets: true,
    optional: false,
    type: "scope",
    fields: [
        {
            name: "name",
            type: "string",
            description: "The name of the array",
            required: true,
        },
        {
            name: "code",
            type: "function",
            description: "The code to execute",
            required: true,
        },
    ],
    description: "for each element in the array, execute the condition",
    default: ["void", "void"],
    returns: "void",
    version: "7.0.0",
    example: `
        $arrayCreate[myArray;hello;world;nya]
        $arrayForEach[myArray;$log[$env[array_element]]] // logs "hello", "world", "nya"
    `,
    code: (data, scope) => {
        const [name, ...values] = data.splits;
        const currentScope = scope[scope.length - 1];
        if (!currentScope.variables.includes(name) &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_"))
            throw new error_js_1.TranspilerError(`${data.name}: Variable ${name} does not exists`);
        const condition = values.join(";");
        const conditionFunctionList = (0, transpilerHelpers_js_1.getFunctionList)(condition, Object.keys(index_js_1.functions));
        let executedCondition;
        if (conditionFunctionList.length) {
            executedCondition = (0, index_js_1.Transpiler)(condition, {
                sendMessage: false,
                scopeData: {
                    variables: currentScope.variables,
                    name: currentScope.name,
                    objects: currentScope.objects,
                    env: [...currentScope.env, "array_element"],
                },
                client: currentScope.client,
            });
            currentScope.functions +=
                executedCondition.scope[0].functions + "\n";
            currentScope.packages += executedCondition.scope[0].packages;
            executedCondition = executedCondition.code;
        }
        else {
            executedCondition = condition;
        }
        executedCondition = (0, index_js_1.conditionLexer)(executedCondition);
        executedCondition = executedCondition.solve();
        const res = (0, transpilerHelpers_js_1.escapeResult)(`${(0, transpilerHelpers_js_1.escapeVars)(name)}.forEach(async array_element => {
                ${(0, transpilerHelpers_js_1.parseResult)(executedCondition)}
            })`);
        currentScope.update(res, data);
        return {
            code: res,
            scope,
            data,
        };
    },
};
//# sourceMappingURL=$arrayForEach.js.map