"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$arrayIncludes = void 0;
const error_js_1 = require("../../../core/error.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$arrayIncludes = {
    name: "$arrayIncludes",
    brackets: true,
    optional: false,
    type: "getter",
    fields: [
        {
            name: "array",
            type: "string",
            description: "The name of the array",
            required: true,
        },
        {
            name: "value",
            type: "string",
            description: "The value to check",
            required: true,
        },
    ],
    description: "Checks if array includes value",
    default: ["void", "void"],
    returns: "boolean",
    version: "7.0.0",
    example: `
        $arrayCreate[myArray;hello;world;nya]
        $arrayIncludes[myArray;hello] // returns true
        $arrayIncludes[myArray;hi] // returns false
    `,
    code: (data, scope) => {
        const currentScope = scope[scope.length - 1];
        const [name, value] = data.splits;
        if (!currentScope.variables.includes(name) &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_"))
            throw new error_js_1.TranspilerError(`${data.name}: Array ${name} does not exist`);
        const res = (0, transpilerHelpers_js_1.escapeResult)(`${(0, transpilerHelpers_js_1.escapeVars)(name)}.includes(${value})`);
        currentScope.update(res, data);
        return {
            code: res,
            scope,
        };
    },
};
//# sourceMappingURL=$arrayIncludes.js.map