"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$arrayLength = void 0;
const error_js_1 = require("../../../core/error.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$arrayLength = {
    name: "$arrayLength",
    brackets: true,
    optional: false,
    type: "getter",
    fields: [
        {
            name: "array",
            type: "string",
            description: "The name of the array",
            required: true,
        },
    ],
    description: "Returns the length of an array.",
    default: ["void"],
    returns: "number",
    version: "7.0.0",
    example: `
        $arrayCreate[myArray;hello;world;nya]
        $arrayLength[myArray] // returns 3
    `,
    code: (data, scope) => {
        const currentScope = scope[scope.length - 1];
        const name = data.inside;
        if (!currentScope.variables.includes(name) &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_"))
            throw new error_js_1.TranspilerError(`${data.name}: Array ${name} does not exist`);
        const res = (0, transpilerHelpers_js_1.escapeResult)(`${(0, transpilerHelpers_js_1.escapeVars)(name)}.length`);
        currentScope.update(res, data);
        return {
            code: res,
            scope,
        };
    },
};
//# sourceMappingURL=$arrayLength.js.map