"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$arrayMap = void 0;
const error_js_1 = require("../../../core/error.js");
const index_js_1 = require("../../../index.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$arrayMap = {
    name: "$arrayMap",
    brackets: true,
    optional: false,
    type: "scope_getter",
    fields: [
        {
            name: "name",
            type: "string",
            required: true,
        },
        {
            name: "query",
            type: "function",
            required: true,
        },
    ],
    description: "maps the array based on the code",
    default: ["void", "void"],
    returns: "array",
    version: "7.0.0",
    example: `
        $arrayCreate[myArray;1;2;3;4;5]
        $arrayMap[myArray;$sum[$env[array_element];1]] // returns [2,3,4,5,6]
    `,
    code: (data, scope) => {
        const [name, ...values] = data.splits;
        const currentScope = scope[scope.length - 1];
        if (!currentScope.variables.includes(name) &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_"))
            throw new error_js_1.TranspilerError(`${data.name}: Variable ${name} does not exists`);
        const code = values.join(";");
        const codeFunctionList = (0, transpilerHelpers_js_1.getFunctionList)(code, Object.keys(index_js_1.functions));
        let executedCode;
        if (codeFunctionList.length) {
            executedCode = (0, index_js_1.Transpiler)(code, {
                sendMessage: false,
                scopeData: {
                    variables: currentScope.variables,
                    name: currentScope.name,
                    objects: currentScope.objects,
                    env: [...currentScope.env, "array_element"],
                },
                client: currentScope.client,
            });
            currentScope.functions += executedCode.scope[0].functions + "\n";
            currentScope.packages += executedCode.scope[0].packages;
            executedCode = executedCode.code;
        }
        else {
            executedCode = code;
        }
        const res = (0, transpilerHelpers_js_1.escapeResult)(`
                ${(0, transpilerHelpers_js_1.escapeVars)(name)}.map(array_element => {
                    ${executedCode}
                    })`);
        currentScope.update(res, data);
        return {
            code: res,
            scope,
            data,
        };
    },
};
//# sourceMappingURL=$arrayMap.js.map