"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$arrayPop = void 0;
const error_js_1 = require("../../../core/error.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$arrayPop = {
    name: "$arrayPop",
    brackets: true,
    optional: false,
    type: "getter",
    fields: [
        {
            name: "array",
            type: "string",
            description: "The name of the array",
            required: true,
        },
    ],
    description: "Removes the last element from an array and returns that element. This method changes the length of the array.",
    default: ["void"],
    returns: "any",
    version: "7.0.0",
    example: `
        $arrayCreate[myArray;hello;world;nya]
        $arrayPop[myArray] // returns nya
    `,
    code: (data, scope) => {
        const currentScope = scope.at(-1);
        const name = data.inside;
        if (!currentScope.variables.includes(name) &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_"))
            throw new error_js_1.TranspilerError(`${data.name}: Array ${name} does not exist`);
        const res = (0, transpilerHelpers_js_1.escapeResult)(`${(0, transpilerHelpers_js_1.escapeVars)(name)}.pop()`);
        return {
            code: res,
            scope,
        };
    },
};
//# sourceMappingURL=$arrayPop.js.map