"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$and = void 0;
const index_js_1 = require("../../../index.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$and = {
    name: "$and",
    type: "getter",
    brackets: true,
    optional: false,
    version: "7.0.0",
    fields: [
        {
            name: "condition",
            type: "string",
            description: "The condition to check",
            required: true,
        },
    ],
    default: ["void"],
    returns: "boolean",
    description: "Returns true if all conditions are true ( function version of && )",
    example: `
    $and[$isNumber[1];$isNumber[2]] // returns true 
    $and[$isNumber[1];$isNumber[hello]] // returns false
    `,
    code: (data, scope) => {
        const conditions = data.splits;
        const currentScope = scope[scope.length - 1];
        const solved = (0, index_js_1.conditionLexer)(conditions.join("&&")).solve();
        const res = (0, transpilerHelpers_js_1.escapeFunctionResult)((0, transpilerHelpers_js_1.parseResult)(solved));
        currentScope.update(res, data);
        return {
            code: res,
            scope,
            data,
        };
    },
};
//# sourceMappingURL=$and.js.map