"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$checkCondition = void 0;
const index_js_1 = require("../../../index.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$checkCondition = {
    name: "$checkCondition",
    type: "getter",
    brackets: true,
    optional: false,
    version: "7.0.0",
    fields: [
        {
            name: "condition",
            type: "string",
            description: "The condition to check",
            required: true,
        },
    ],
    default: ["void"],
    returns: "boolean",
    description: "Returns true if the condition is true",
    example: `
    $checkCondition[$isNumber[1]] // returns true

    $checkCondition[hello === world] // returns false
    `,
    code: (data, scope) => {
        const conditions = data.inside;
        const currentScope = scope[scope.length - 1];
        const solved = (0, index_js_1.conditionLexer)(conditions).solve();
        const res = (0, transpilerHelpers_js_1.escapeResult)((0, transpilerHelpers_js_1.parseResult)(solved));
        currentScope.update(res, data);
        return {
            code: res,
            scope,
        };
    },
};
//# sourceMappingURL=$checkCondition.js.map