"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.$if = void 0;
const index_js_1 = require("../../../index.js");
const index_js_2 = __importDefault(require("../../index.js"));
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$if = {
    name: "$if",
    brackets: true,
    optional: false,
    type: "scope",
    fields: [
        {
            name: "condition",
            type: "string",
            description: "The condition to check",
            required: true,
        },
        {
            name: "code",
            type: "string",
            description: "The code to execute if the if statement is true",
            required: true,
        },
    ],
    version: "7.0.0",
    default: ["void", "void"],
    returns: "void",
    description: "If statement",
    example: `
        $if[$ping<100;
        $log[ping is less than 100]
    ]
    $elseIf[$ping<200;
        $log[ping is less than 200]
    ]
    $else[
        $log[ping is greater than 200]
    ]
    `,
    code: (data, scope) => {
        const splits = data.splits;
        const currentScope = scope[scope.length - 1];
        if (exports.$if.brackets) {
            if (!data.total.startsWith(exports.$if.name + "[") &&
                (!currentScope.name.startsWith("$try_") ||
                    !currentScope.name.startsWith("$catch_"))) {
                throw new index_js_1.TranspilerError(`${data.name} requires closure brackets`);
            }
        }
        const [condition, ...errorMsg] = splits;
        const conditionFunctionList = (0, transpilerHelpers_js_1.getFunctionList)(condition, Object.keys(index_js_2.default));
        let executedCondition;
        if (conditionFunctionList.length) {
            executedCondition = (0, index_js_1.Transpiler)(condition, {
                sendMessage: false,
                scopeData: {
                    variables: currentScope.variables,
                    name: currentScope.name,
                    objects: currentScope.objects,
                    env: currentScope.env,
                },
                client: currentScope.client,
            });
            currentScope.functions +=
                executedCondition.scope[0].functions + "\n";
            currentScope.packages += executedCondition.scope[0].packages;
            executedCondition = executedCondition.code;
        }
        else {
            executedCondition = condition;
        }
        executedCondition = (0, index_js_1.conditionLexer)(executedCondition);
        executedCondition = executedCondition.solve();
        const hash = Math.floor(Math.random() * 100000);
        const newscope = new index_js_1.Scope(`${data.name}_${hash}`, currentScope.client, currentScope.name, errorMsg.join(";"), true);
        let executedErrorMsg;
        const errorMsgFunctionList = (0, transpilerHelpers_js_1.getFunctionList)(errorMsg.join(";"), Object.keys(index_js_2.default));
        if (errorMsgFunctionList.length) {
            executedErrorMsg = (0, index_js_1.Transpiler)(errorMsg.join(";"), {
                sendMessage: true,
                scopeData: {
                    variables: currentScope.variables,
                    embeds: currentScope.embeds,
                    name: currentScope.name,
                    objects: currentScope.objects,
                    env: currentScope.env,
                },
                client: currentScope.client,
            });
            newscope.functions = executedErrorMsg.scope[0].functions + "\n";
            newscope.packages = executedErrorMsg.scope[0].packages + "\n";
            newscope.setters = executedErrorMsg.scope[0].setters + "\n";
            executedErrorMsg.scope[0].addReturn = true;
            newscope.rest = executedErrorMsg.scope[0].rest + "\n";
            newscope.sendData = executedErrorMsg.scope[0].sendData;
        }
        else {
            executedErrorMsg = errorMsg.join(";");
            newscope.rest = executedErrorMsg + "\n";
            newscope.sendData.content = executedErrorMsg;
        }
        const res = (0, transpilerHelpers_js_1.escapeFunctionResult)(`
    if(${executedCondition}) {
      ${newscope.toString()}
    }
    `);
        currentScope.update(res, data);
        return {
            code: res,
            scope: scope,
            data,
        };
    },
};
//# sourceMappingURL=$if.js.map