"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.$onlyIf = void 0;
const index_js_1 = require("../../../index.js");
const index_js_2 = __importDefault(require("../../index.js"));
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$onlyIf = {
    name: "$onlyIf",
    brackets: true,
    optional: false,
    type: "scope",
    fields: [
        {
            name: "condition",
            type: "string",
            description: "The condition to check",
            required: true,
        },
        {
            name: "errorMsg",
            type: "string",
            description: "The error message to send if the condition is false",
            required: false,
        },
    ],
    version: "7.0.0",
    default: ["void", ""],
    returns: "void",
    description: "onlyIf statement",
    example: `
        $onlyIf[$ping<100;
        $log[ping is less than 100]
    ]`,
    code: (data, scope) => {
        const splits = data.splits;
        const currentScope = scope[scope.length - 1];
        if (exports.$onlyIf.brackets) {
            if (!data.total.startsWith(exports.$onlyIf.name + "[") &&
                (!currentScope.name.startsWith("$try_") ||
                    !currentScope.name.startsWith("$catch_"))) {
                throw new index_js_1.TranspilerError(`${data.name} requires closure brackets`);
            }
        }
        const [condition, ...errorMsg] = splits;
        const conditionFunctionList = (0, transpilerHelpers_js_1.getFunctionList)(condition, Object.keys(index_js_2.default));
        let executedCondition;
        if (conditionFunctionList.length) {
            executedCondition = (0, index_js_1.Transpiler)(condition, {
                sendMessage: false,
                scopeData: {
                    variables: currentScope.variables,
                    name: currentScope.name,
                    objects: currentScope.objects,
                    env: currentScope.env,
                },
                client: currentScope.client,
            });
            currentScope.functions +=
                executedCondition.scope[0].functions + "\n";
            currentScope.packages += executedCondition.scope[0].packages;
            executedCondition = executedCondition.code;
        }
        else {
            executedCondition = condition;
        }
        executedCondition = (0, index_js_1.conditionLexer)(executedCondition);
        executedCondition = executedCondition.solve();
        const hash = Math.floor(Math.random() * 100000);
        const newscope = new index_js_1.Scope(`${data.name}_${hash}`, currentScope.client, currentScope.name, errorMsg.join(";"), true);
        let executedErrorMsg;
        const errorMsgFunctionList = (0, transpilerHelpers_js_1.getFunctionList)(errorMsg.join(";"), Object.keys(index_js_2.default));
        if (errorMsgFunctionList.length) {
            executedErrorMsg = (0, index_js_1.Transpiler)(errorMsg.join(";"), {
                sendMessage: false,
                scopeData: {
                    variables: currentScope.variables,
                    name: currentScope.name,
                    objects: currentScope.objects,
                    env: currentScope.env,
                },
                client: currentScope.client,
            });
            newscope.functions = executedErrorMsg.scope[0].functions + "\n";
            newscope.packages = executedErrorMsg.scope[0].packages + "\n";
            newscope.setters = executedErrorMsg.scope[0].setters + "\n";
            newscope.rest = executedErrorMsg.scope[0].rest + "\n";
            newscope.sendData = executedErrorMsg.scope[0].sendData;
            newscope.embeds = executedErrorMsg.scope[0].embeds;
            newscope.components = executedErrorMsg.scope[0].components;
            newscope.files = executedErrorMsg.scope[0].files;
            newscope.stickers = executedErrorMsg.scope[0].stickers;
            newscope.variables = executedErrorMsg.scope[0].variables;
        }
        else {
            executedErrorMsg = errorMsg.join(";");
            newscope.rest = executedErrorMsg + "\n";
            newscope.sendData.content = executedErrorMsg;
        }
        newscope.addReturn = true;
        const res = (0, transpilerHelpers_js_1.escapeResult)(`
    if(!(${executedCondition})) {
      ${newscope.toString(true)}
      return ;
    }
    `);
        currentScope.rest = currentScope.rest.replace(data.total, res);
        return {
            code: res,
            scope: scope,
            data,
        };
    },
};
//# sourceMappingURL=$onlyif.js.map