"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$or = void 0;
const index_js_1 = require("../../../index.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$or = {
    name: "$or",
    type: "getter",
    brackets: true,
    optional: false,
    version: "7.0.0",
    fields: [
        {
            name: "condition",
            type: "string",
            description: "The condition to check",
            required: true,
        },
    ],
    default: ["void"],
    returns: "boolean",
    description: "Returns true if any condition is true",
    example: `
    $or[$isNumber[1];$isNumber[2]] // returns true
    $or[$isNumber[1];$isNumber[abc]] // returns true
    `,
    code: (data, scope) => {
        const conditions = data.splits;
        const currentScope = scope[scope.length - 1];
        const solved = (0, index_js_1.conditionLexer)(conditions.join("||")).solve();
        const res = (0, transpilerHelpers_js_1.escapeResult)((0, transpilerHelpers_js_1.parseResult)(solved));
        currentScope.update(res, data);
        return {
            code: res,
            scope,
        };
    },
};
//# sourceMappingURL=$or.js.map