"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.$loop = void 0;
const index_js_1 = require("../../../index.js");
const StringObject_js_1 = __importDefault(require("../../../core/structs/StringObject.js"));
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
const index_js_2 = __importDefault(require("../../index.js"));
exports.$loop = {
    name: "$loop",
    type: "scope",
    brackets: true,
    optional: false,
    fields: [
        {
            name: "times",
            type: "number",
            description: "The times to loop",
            required: true,
        },
        {
            name: "extraData",
            type: "json",
            description: "The extra data to send to the loop",
            required: true,
        },
        {
            name: "code",
            type: "string",
            description: "The code to execute",
            required: true,
        },
    ],
    version: "7.0.0",
    default: ["void", "void", "void"],
    returns: "void",
    description: "Loop statement",
    example: `
        $loop[5;{name: hello, age: 12};$log[hello world]]
    `,
    code: (data, scope) => {
        const splits = data.splits;
        const currentScope = scope[scope.length - 1];
        if (data.inside?.trim() === "" ||
            (!data.inside &&
                (!currentScope.name.startsWith("$try_") ||
                    !currentScope.name.startsWith("$catch_")))) {
            throw new index_js_1.TranspilerError(`${data.name} function requires condition and code`);
        }
        if (data.splits.length < 2 &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new index_js_1.TranspilerError(`${data.name} function requires condition and code`);
        }
        const [times, extraData, ...code] = splits;
        if (isNaN(Number(times)) &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new index_js_1.TranspilerError(`${data.name} function requires times field as number`);
        }
        const currentObj = new StringObject_js_1.default("{");
        currentObj.addEnd("}");
        let object;
        try {
            object = (0, index_js_1.parseStringObject)(extraData, currentObj);
        }
        catch (e) {
            throw new index_js_1.TranspilerError(`${data.name}: Invalid Object Provided`);
        }
        currentScope.env.push(...object.keys.map((x) => `loop_${x}`));
        currentScope.env.push("loop_index");
        let executedCode;
        const codeFunctionList = (0, transpilerHelpers_js_1.getFunctionList)(code.join(";"), Object.keys(index_js_2.default));
        if (code.join(";").startsWith("{execute:") &&
            code.join(";").endsWith("}")) {
            object.keys = object.keys.map((x) => `loop_${x}`);
            const [name, type] = code
                .join(";")
                .split("{execute:")[1]
                .split("}")[0]
                .split(":");
            executedCode = `__$DISCORD_DATA$__.bot.cmds.get("${name}", "${type}").code({...__$DISCORD_DATA$__, ...${object.solve()} })`;
        }
        else if (codeFunctionList.length) {
            executedCode = (0, index_js_1.Transpiler)(code.join(";"), {
                sendMessage: false,
                scopeData: {
                    variables: currentScope.variables,
                    embeds: currentScope.embeds,
                    name: currentScope.name,
                    objects: currentScope.objects,
                    env: currentScope.env,
                },
                client: currentScope.client,
            });
        }
        else {
            executedCode = code.join(";");
        }
        const res = (0, transpilerHelpers_js_1.escapeResult)(`
for(let loop_index = 0; loop_index < ${times}; loop_index++) {
      ${typeof executedCode === "string"
            ? executedCode
            : (executedCode)?.scope[0].toString(false)}
}
`);
        currentScope.update(res, data);
        return { code: res, scope: scope, data };
    },
};
//# sourceMappingURL=$loop.js.map