"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.$while = void 0;
const index_js_1 = require("../../../index.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
const index_js_2 = __importDefault(require("../../index.js"));
exports.$while = {
    name: "$while",
    type: "scope",
    brackets: true,
    optional: false,
    fields: [
        {
            name: "condition",
            type: "string",
            description: "The condition to check",
            required: true,
        },
        {
            name: "code",
            type: "string",
            description: "The code to execute if the while statement is true",
            required: true,
        },
    ],
    version: "1.0.0",
    default: ["void", "void"],
    returns: "void",
    description: "While statement",
    example: `
        $let[num;1]
        $while[$get[num] < 5;
            $log[hello world]
            $inc[$get[num]]
        ]
    `,
    code: (data, scope) => {
        const splits = data.splits;
        const currentScope = scope[scope.length - 1];
        if (data.inside?.trim() === "" ||
            (!data.inside &&
                (!currentScope.name.startsWith("$try_") ||
                    !currentScope.name.startsWith("$catch_")))) {
            throw new index_js_1.TranspilerError(`${data.name} function requires condition and code`);
        }
        if (data.splits.length < 2 &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new index_js_1.TranspilerError(`${data.name} function requires condition and code`);
        }
        const [condition, ...code] = splits;
        const conditionFunctionList = (0, transpilerHelpers_js_1.getFunctionList)(condition, Object.keys(index_js_2.default));
        let executedCondition;
        if (conditionFunctionList.length) {
            executedCondition = (0, index_js_1.Transpiler)(condition, {
                sendMessage: false,
                scopeData: {
                    variables: currentScope.variables,
                    name: currentScope.name,
                    objects: currentScope.objects,
                    env: currentScope.env,
                },
                client: currentScope.client,
            });
            currentScope.functions +=
                executedCondition.scope[0].functions + "\n";
            currentScope.packages += executedCondition.scope[0].packages;
            executedCondition = executedCondition.code;
        }
        else {
            executedCondition = condition;
        }
        executedCondition = (0, index_js_1.conditionLexer)(executedCondition);
        executedCondition = executedCondition.solve();
        let executedCode;
        const codeFunctionList = (0, transpilerHelpers_js_1.getFunctionList)(code.join(";"), Object.keys(index_js_2.default));
        if (codeFunctionList.length) {
            executedCode = (0, index_js_1.Transpiler)(code.join(";"), {
                sendMessage: false,
                scopeData: {
                    variables: currentScope.variables,
                    embeds: currentScope.embeds,
                    name: currentScope.name,
                    objects: currentScope.objects,
                    env: currentScope.env,
                },
                client: currentScope.client,
            });
        }
        else {
            executedCode = code.join(";");
        }
        const res = (0, transpilerHelpers_js_1.escapeResult)(`
while(${executedCondition}) {
   ${typeof executedCode === "string"
            ? executedCode
            : (executedCode)?.scope[0].toString(false)}
}
`);
        currentScope.update(res, data);
        return { code: res, scope: scope, data };
    },
};
//# sourceMappingURL=$while.js.map