"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$abs = void 0;
const error_js_1 = require("../../../core/error.js");
const enums_js_1 = require("../../../typings/enums.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$abs = {
    name: "$abs",
    type: "getter",
    brackets: true,
    optional: false,
    fields: [
        {
            name: "number",
            type: "number",
            description: "The number to get the absolute value from",
            required: true,
        },
    ],
    version: "7.0.0",
    default: ["void"],
    returns: "number",
    description: "Returns the Absolute value of the number",
    example: `
    $abs[1] // returns 1
    $abs[-1] // returns 1
    `,
    code: (data, scope) => {
        const numbers = data.inside;
        const currentScope = scope[scope.length - 1];
        if (data.splits.length === 0 &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name} requires at least 1 argument`);
        }
        if (!numbers)
            throw new error_js_1.TranspilerError(`${data.name} requires at least 1 argument`);
        let abs = numbers.includes(enums_js_1.TranspilerCustoms.FS) ||
            numbers.includes("__$DISCORD_DATA$__") ||
            numbers.includes(enums_js_1.TranspilerCustoms.MFS)
            ? (0, transpilerHelpers_js_1.parseResult)(numbers.trim())
            : Number(numbers);
        abs = `Math.abs(${abs})`;
        const res = (0, transpilerHelpers_js_1.escapeMathResult)(`(${abs})`);
        currentScope.update(res, data);
        return {
            code: res,
            scope,
        };
    },
};
//# sourceMappingURL=$abs.js.map