"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$multi = void 0;
const error_js_1 = require("../../../core/error.js");
const enums_js_1 = require("../../../typings/enums.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$multi = {
    name: "$multi",
    type: "getter",
    brackets: true,
    optional: false,
    fields: [
        {
            name: "numbers",
            type: "number",
            description: "The numbers to multiply",
            required: true,
        },
    ],
    version: "7.0.0",
    default: ["void"],
    returns: "number",
    description: "Returns the multiplication of the numbers",
    example: `
    $multi[1;2] // returns 2
    $multi[1;2;3] // returns 6
    `,
    code: (data, scope) => {
        const numbers = data.splits;
        const currentScope = scope[scope.length - 1];
        if (data.splits.length === 0 &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name} requires at least 1 argument`);
        }
        const multi = numbers
            .map((x) => x.includes(enums_js_1.TranspilerCustoms.FS) ||
            x.includes("__$DISCORD_DATA$__") ||
            x.includes(enums_js_1.TranspilerCustoms.MFS)
            ? (0, transpilerHelpers_js_1.parseResult)(x.trim())
            : Number(x))
            .join("*");
        const res = (0, transpilerHelpers_js_1.escapeMathResult)(`(${multi})`);
        currentScope.rest = currentScope.rest.replace(data.total, res);
        return {
            code: res,
            scope,
        };
    },
};
//# sourceMappingURL=$multi.js.map