"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$pow = void 0;
const error_js_1 = require("../../../core/error.js");
const enums_js_1 = require("../../../typings/enums.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$pow = {
    name: "$pow",
    type: "getter",
    brackets: true,
    optional: false,
    fields: [
        {
            name: "numbers",
            type: "number",
            description: "The numbers to get the power from",
            required: true,
        },
    ],
    version: "7.0.0",
    default: ["void"],
    returns: "number",
    description: "Returns the power of the numbers",
    example: `
    $pow[1;2] // returns 1
    $pow[7;4;3] // returns 2401
    `,
    code: (data, scope) => {
        const numbers = data.splits;
        const currentScope = scope[scope.length - 1];
        if (data.splits.length === 0 &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name} requires at least 1 argument`);
        }
        const pow = numbers
            .map((x) => x.includes(enums_js_1.TranspilerCustoms.FS) ||
            x.includes("__$DISCORD_DATA$__") ||
            x.includes(enums_js_1.TranspilerCustoms.MFS)
            ? (0, transpilerHelpers_js_1.parseResult)(x.trim())
            : Number(x))
            .join("**");
        const res = (0, transpilerHelpers_js_1.escapeMathResult)(`(${pow})`);
        currentScope.update(res, data);
        return {
            code: res,
            scope,
        };
    },
};
//# sourceMappingURL=$pow.js.map