"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$round = void 0;
const error_js_1 = require("../../../core/error.js");
const enums_js_1 = require("../../../typings/enums.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$round = {
    name: "$round",
    type: "getter",
    brackets: true,
    optional: false,
    fields: [
        {
            name: "number",
            type: "number",
            description: "The number to round off",
            required: true,
        }, {
            name: "decimal",
            type: "number",
            description: "The decimal to round off",
            required: false,
        }
    ],
    version: "7.0.0",
    default: ["void"],
    returns: "number",
    description: "Returns the Roundo off value of the number",
    example: `
    $round[1;2] // returns 1.00
    $round[1.2;0] // returns 1
    `,
    code: (data, scope) => {
        const [number, decimal = "0"] = data.splits;
        const currentScope = scope[scope.length - 1];
        if (data.splits.length === 0 &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name} requires at least 1 argument`);
        }
        if (!number)
            throw new error_js_1.TranspilerError(`${data.name} requires at least 1 argument`);
        let round = number.includes(enums_js_1.TranspilerCustoms.FS) ||
            number.includes("__$DISCORD_DATA$__") ||
            number.includes(enums_js_1.TranspilerCustoms.MFS)
            ? (0, transpilerHelpers_js_1.parseResult)(number.trim())
            : Number(number);
        const rounddecimal = decimal.includes(enums_js_1.TranspilerCustoms.FS) ||
            decimal.includes("__$DISCORD_DATA$__") ||
            decimal.includes(enums_js_1.TranspilerCustoms.MFS)
            ? (0, transpilerHelpers_js_1.parseResult)(decimal.trim())
            : Number(decimal);
        round = `((${round}).toFixed(${rounddecimal}))`;
        const res = (0, transpilerHelpers_js_1.escapeMathResult)(`(${round})`);
        currentScope.update(res, data);
        return {
            code: res,
            scope,
        };
    },
};
//# sourceMappingURL=$round.js.map