"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$truncate = void 0;
const error_js_1 = require("../../../core/error.js");
const enums_js_1 = require("../../../typings/enums.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$truncate = {
    name: "$truncate",
    type: "getter",
    brackets: true,
    optional: false,
    fields: [
        {
            name: "number",
            type: "number",
            description: "The number to truncate off",
            required: true,
        },
    ],
    version: "7.0.0",
    default: ["void"],
    returns: "number",
    description: "Returns the Truncate off value of the number",
    example: `
    $truncate[1.22342] // returns 1
`,
    code: (data, scope) => {
        const number = data.inside ?? "";
        const currentScope = scope[scope.length - 1];
        if (data.splits.length === 0 &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name} requires at least 1 argument`);
        }
        if (!number)
            throw new error_js_1.TranspilerError(`${data.name} requires at least 1 argument`);
        let truncate = number.includes(enums_js_1.TranspilerCustoms.FS) ||
            number.includes("__$DISCORD_DATA$__") ||
            number.includes(enums_js_1.TranspilerCustoms.MFS)
            ? (0, transpilerHelpers_js_1.parseResult)(number.trim())
            : Number(number);
        truncate = `(Math.trunc(${truncate}))`;
        const res = (0, transpilerHelpers_js_1.escapeMathResult)(`(${truncate})`);
        currentScope.update(res, data);
        return {
            code: res,
            scope,
        };
    },
};
//# sourceMappingURL=$truncate.js.map