"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.$catch = void 0;
const index_js_1 = require("../../../index.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
const index_js_2 = __importDefault(require("../../index.js"));
exports.$catch = {
    name: "$catch",
    brackets: true,
    optional: false,
    type: "scope",
    fields: [
        {
            name: "code",
            type: "string",
            description: "The code to execute if the try statement fails",
            required: true,
        },
    ],
    version: "7.0.0",
    description: "catch statement that executes when try fails",
    default: ["void"],
    returns: "void",
    example: `
        $try[
            $let[;1]
        ]
        $catch[
            $log[ 
                $env[catch_error]
            ]
        ]
    `,
    code: (data, scope) => {
        const code = data.inside;
        if (!code) {
            throw new index_js_1.TranspilerError(`${data.name}: Code Not Provided.`);
        }
        const currentScope = scope[scope.length - 1];
        const hash = Math.floor(Math.random() * 1000000);
        const newscope = new index_js_1.Scope(`${data.name}_${hash}`, currentScope.client, currentScope.name, (0, transpilerHelpers_js_1.parseResult)(code), true);
        let codeexe;
        const funcList = (0, transpilerHelpers_js_1.getFunctionList)(code, Object.keys(index_js_2.default));
        if (!funcList.length) {
            codeexe = code;
        }
        else {
            codeexe = (0, index_js_1.Transpiler)(code, {
                sendMessage: true,
                scopeData: {
                    variables: currentScope.variables,
                    embeds: currentScope.embeds,
                    name: newscope.name,
                    env: ["catch_error"],
                },
                client: currentScope.client,
            });
            newscope.functions = codeexe.scope[0].functions + "\n";
            newscope.packages = codeexe.scope[0].packages + "\n";
            newscope.setters = codeexe.scope[0].setters + "\n";
            newscope.rest = codeexe.scope[0].rest + "\n";
            newscope.sendData = codeexe.scope[0].sendData;
            newscope.embeds = codeexe.scope[0].embeds;
            newscope.components = codeexe.scope[0].components;
            newscope.files = codeexe.scope[0].files;
            newscope.stickers = codeexe.scope[0].stickers;
            newscope.variables = codeexe.scope[0].variables;
        }
        const res = (0, transpilerHelpers_js_1.escapeResult)(`catch(catch_error) {
        ${newscope.toString(true)}
    }`);
        currentScope.rest = currentScope.rest.replace(data.total, res);
        data.funcs = [];
        return {
            code: res,
            scope: scope,
            data,
        };
    },
};
//# sourceMappingURL=$catch.js.map