"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$get = void 0;
const error_js_1 = require("../../../core/error.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$get = {
    name: "$get",
    brackets: true,
    optional: false,
    type: "getter",
    fields: [
        {
            name: "name",
            type: "string",
            description: "The name of the variable to get",
            required: true,
        },
    ],
    version: "7.0.0",
    default: ["void"],
    returns: "any",
    description: "Gets the value of the variable",
    example: `
        $let[hello;world]
        $get[hello] // returns world
    `,
    code: (data, scope) => {
        const splits = data.splits;
        const currentScope = scope[scope.length - 1];
        if (exports.$get.brackets) {
            if (!data.total.startsWith(exports.$get.name + "[") &&
                (!currentScope.name.startsWith("$try_") ||
                    !currentScope.name.startsWith("$catch_"))) {
                throw new error_js_1.TranspilerError(`${data.name} requires closure brackets`);
            }
        }
        if (splits.length !== 1 &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name} requires 1 argument`);
        }
        const name = (0, transpilerHelpers_js_1.removeSetFunc)(splits[0]);
        if (name === "" &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name} requires a name`);
        }
        if (!currentScope.variables.includes(name) &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name} cannot find ${name}`);
        }
        const res = `${(0, transpilerHelpers_js_1.escapeResult)((0, transpilerHelpers_js_1.escapeVars)(name))}`;
        currentScope.update(res, data);
        return { code: res, scope: scope };
    },
};
//# sourceMappingURL=$get.js.map