"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$jseval = void 0;
const index_js_1 = require("../../../index.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$jseval = {
    name: "$jseval",
    brackets: true,
    optional: false,
    type: "function_getter",
    fields: [
        {
            name: "output",
            type: "string",
            description: "Whether to output the result of the code",
            required: true,
        },
        {
            name: "code",
            type: "string",
            description: "The code to evaluate",
            required: true,
        },
    ],
    version: "1.0.0",
    default: ["void", "void"],
    returns: "any",
    description: "Evaluates the provided Js code",
    example: `
        $jsEval[false;log("hello world")]
    `,
    code: (data, scope) => {
        const splits = data.splits;
        const [output, ...code] = splits;
        const currentScope = scope[scope.length - 1];
        const parsedOutput = (0, transpilerHelpers_js_1.convertToBool)(output);
        if (exports.$jseval.brackets) {
            if (!data.total.startsWith(exports.$jseval.name + "[") &&
                (!currentScope.name.startsWith("$try_") ||
                    !currentScope.name.startsWith("$catch_"))) {
                throw new index_js_1.TranspilerError(`${data.name} requires closure brackets`);
            }
        }
        if (splits.length < 2 &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new index_js_1.TranspilerError(`${data.name} requires 2 arguments`);
        }
        const Code = (0, index_js_1.parseString)(code.join(";"));
        if (!currentScope.functions.includes("async function __$jseval$__(Code) {")) {
            const setres = `
    async function __$jsEval$__(Code) {
      try {
        const evaled =  await eval(Code);
        return evaled;
      } catch (e) {
        return e;
      }
    }`;
            currentScope.functions += (0, transpilerHelpers_js_1.escapeResult)(setres) + "\n";
        }
        const res = `${(0, transpilerHelpers_js_1.escapeResult)(`await __$jsEval$__.call(__$DISCORD_DATA$__,${Code})`)}`;
        currentScope.rest = currentScope.rest.replace(data.total, res);
        return {
            code: parsedOutput ? res : "",
            scope: scope,
        };
    },
};
//# sourceMappingURL=$jseval.js.map