"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$let = void 0;
const error_js_1 = require("../../../core/error.js");
const stringParser_js_1 = require("../../../core/parsers/stringParser.js");
const enums_js_1 = require("../../../typings/enums.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$let = {
    name: "$let",
    brackets: true,
    optional: false,
    type: "setter",
    fields: [
        {
            name: "name",
            type: "string",
            description: "The name of the variable to set",
            required: true,
        },
        {
            name: "value",
            type: "string",
            description: "The value to set the variable to",
            required: true,
        },
    ],
    version: "7.0.0",
    default: ["void", "void"],
    returns: "void",
    description: "Sets the value of the variable",
    example: `
        $let[hello;world] // sets the variable hello to world
    `,
    code: (data, scope) => {
        let res;
        const splits = data.splits;
        const currentScope = scope[scope.length - 1];
        // Initial Error Handling
        if (exports.$let.brackets) {
            if (!data.total.startsWith(exports.$let.name + "[") &&
                (!currentScope.name.startsWith("$try_") ||
                    !currentScope.name.startsWith("$catch_"))) {
                throw new error_js_1.TranspilerError(`${data.name} requires closure brackets`);
            }
        }
        if (splits.length < 2 &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name} requires 2 arguments`);
        }
        const name = (0, transpilerHelpers_js_1.removeSetFunc)(splits[0]);
        let value = (0, transpilerHelpers_js_1.parseData)((0, transpilerHelpers_js_1.removeSetFunc)(splits.slice(1).join(";")));
        if (typeof value === "string" &&
            value.includes(enums_js_1.TranspilerCustoms.FS) &&
            !value.includes(enums_js_1.TranspilerCustoms.MFS) &&
            !(!value.split(enums_js_1.TranspilerCustoms.FS)[0] && !value.split(enums_js_1.TranspilerCustoms.FE)[1])) {
            value = (0, stringParser_js_1.parseString)(value);
        }
        // Error handling for name and value
        if (name === "" &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name} requires a name`);
        }
        if (name === value &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name} cannot be used to set itself`);
        }
        if (currentScope.variables.includes(name)) {
            if (currentScope.variables.includes((0, transpilerHelpers_js_1.parseResult)(value)) ||
                value.toString().startsWith(enums_js_1.TranspilerCustoms.FS) ||
                (value.toString().startsWith("`") &&
                    value.toString().endsWith("`")) ||
                value.toString().includes(enums_js_1.TranspilerCustoms.MFS)) {
                res = `${(0, transpilerHelpers_js_1.escapeVars)(name)} = ${value};`;
            }
            else {
                res = `${(0, transpilerHelpers_js_1.escapeVars)(name)} = \`${value}\`;`;
            }
        }
        else {
            if (typeof value !== "string" ||
                currentScope.variables.includes((0, transpilerHelpers_js_1.parseResult)(value.toString())) ||
                value.toString().startsWith(enums_js_1.TranspilerCustoms.FS) ||
                (value.toString().startsWith("`") &&
                    value.toString().endsWith("`")) ||
                value.includes(enums_js_1.TranspilerCustoms.MFS)) {
                res = `let ${(0, transpilerHelpers_js_1.escapeVars)(name)} = ${value};`;
            }
            else {
                res = `let ${(0, transpilerHelpers_js_1.escapeVars)(name)} = \`${value}\`;`;
            }
        }
        currentScope.variables.push(name);
        currentScope.update(res, data);
        scope[scope.length - 1] = currentScope;
        return { code: "", scope: scope };
    },
};
//# sourceMappingURL=$let.js.map