"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.$log = void 0;
const error_js_1 = require("../../../core/error.js");
const mathParser_js_1 = __importDefault(require("../../../core/parsers/mathParser.js"));
const stringParser_js_1 = require("../../../core/parsers/stringParser.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$log = {
    name: "$log",
    brackets: true,
    optional: false,
    type: "function",
    fields: [
        {
            name: "text",
            type: "string",
            description: "The text to log",
            required: true,
        },
    ],
    version: "7.0.0",
    default: ["void"],
    returns: "void",
    description: "Logs the text",
    example: `
        $log[hello world] // logs hello world
    `,
    code: (data, scope) => {
        const splits = data.splits;
        const currentScope = scope[scope.length - 1];
        if (exports.$log.brackets) {
            if (!data.total.startsWith(exports.$log.name + "[") &&
                (!currentScope.name.startsWith("$try_") ||
                    !currentScope.name.startsWith("$catch_"))) {
                throw new error_js_1.TranspilerError(`${data.name} requires closure brackets`);
            }
        }
        if (splits.length !== 1 &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name} requires 1 argument`);
        }
        const text = splits[0];
        if (text === "" &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name} requires a text`);
        }
        const parsedText = (0, stringParser_js_1.parseString)((0, mathParser_js_1.default)(text));
        const res = `${(0, transpilerHelpers_js_1.escapeFunctionResult)(`console.log(${parsedText});`)}`;
        currentScope.update(res, data);
        return { code: res, scope: scope, data };
    },
};
//# sourceMappingURL=$log.js.map