"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$passData = void 0;
const index_js_1 = require("../../../core/index.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$passData = {
    name: "$passData",
    brackets: true,
    optional: false,
    type: "getter",
    fields: [
        {
            name: "passData",
            type: "string",
            description: "access the data passed to the command from another command",
            required: true,
        },
    ],
    description: "return the data passed to the command from another command",
    default: ["void"],
    version: "7.0.0",
    returns: "?string",
    example: `
    $passData[hello] // returns the data passed to the command from another command
`,
    code: (data, scope) => {
        const passData = data.inside;
        const currentScope = scope[scope.length - 1];
        if (!passData &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new index_js_1.TranspilerError(`${data.name}: PASSDATA Not Provided.`);
        }
        const res = (0, transpilerHelpers_js_1.escapeResult)(`__$DISCORD_DATA$__${passData}`);
        currentScope.update(res, data);
        return {
            code: res,
            scope,
        };
    },
};
//# sourceMappingURL=$passData.js.map