"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$useComponent = void 0;
const index_js_1 = require("../../../index.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$useComponent = {
    name: "$useComponent",
    brackets: true,
    optional: false,
    type: "function_getter",
    fields: [
        {
            name: "name",
            type: "string",
            description: "The name of the component to use",
            required: true,
        },
        {
            name: "data",
            type: "object",
            description: "The data to pass to the component",
            required: false,
        },
    ],
    description: "use a component in the code",
    default: ["void", "undefined"],
    returns: "any",
    version: "7.0.0",
    example: `
        $useComponent[hello;{hello: world}] // executes the component hello with the data {hello: world}
    `,
    code: (data, scope) => {
        const currentScope = scope.at(-1);
        //code here
        const [name, ...rest] = data.splits;
        const actualRestData = rest.join(";");
        const currentObj = new index_js_1.StringObject("{");
        currentObj.addEnd("}");
        const obj = (0, index_js_1.parseStringObject)(actualRestData, currentObj);
        const res = (0, transpilerHelpers_js_1.escapeResult)(`
        await (async()=>{
          const Cmp_${name} = await __$Discord_Data$__.bot.executeComponent("${name}",{
            ...__$Discord_Data$__,
            ...${obj.solve()}
          };
          if(!Cmp_${name}.success) throw new Error("Sample Error",{
            component: "${name}",
            success: Cmp_${name}.success,
          });
          return Cmp_${name}.data;
        })().catch((e)=>{throw new Error(e.message);})
          `);
        currentScope.update(res, data);
        return {
            code: res,
            scope,
        };
    },
};
//# sourceMappingURL=$useComponent.js.map