"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$cloneObject = void 0;
const error_js_1 = require("../../../core/error.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$cloneObject = {
    name: "$cloneObject",
    brackets: true,
    optional: false,
    type: "setter",
    version: "7.0.0",
    fields: [
        {
            name: "name",
            type: "string",
            description: "The name of the object to clone",
            required: true,
        },
        {
            name: "target",
            type: "string",
            description: "The name of the object to clone to",
            required: true,
        },
    ],
    description: "clones an Object",
    default: ["void", "void"],
    returns: "void",
    example: `
        $createObject[object;{key:value}]
        $cloneObject[object;object2]
        $getObjectProperty[object2;key] // returns value
    `,
    code: (data, scope) => {
        const currentScope = scope[scope.length - 1];
        const [name, target] = data.splits;
        if (!currentScope.objects[name] &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name}: Invalid Object Name Provided`);
        }
        currentScope.objects[target] = currentScope.objects[name];
        const res = (0, transpilerHelpers_js_1.escapeResult)(`const ${(0, transpilerHelpers_js_1.escapeVars)(target)} =  structuredClone(${(0, transpilerHelpers_js_1.escapeVars)(name)});`);
        currentScope.update(res, data);
        return {
            code: "",
            scope,
        };
    },
};
//# sourceMappingURL=$cloneObject.js.map