"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$createObject = void 0;
const error_js_1 = require("../../../core/error.js");
const index_js_1 = require("../../../index.js");
const enums_js_1 = require("../../../typings/enums.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$createObject = {
    name: "$createObject",
    brackets: true,
    optional: false,
    type: "setter",
    version: "7.0.0",
    fields: [
        {
            name: "name",
            type: "string",
            description: "The name of the object to create",
            required: true,
        },
        {
            name: "object",
            type: "json",
            description: "The object to create",
            required: true,
        },
    ],
    description: "creates an Object",
    default: ["void", "void"],
    returns: "void",
    example: `
        $createObject[object;{key:value}]
        $getObjectProperty[object;key] // returns value
    `,
    code: (data, scope) => {
        const currentScope = scope[scope.length - 1];
        const [name, ...obj] = data.splits;
        const parsedObj = obj.join(";").trim();
        if (!obj.length &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name}: No Object Provided`);
        }
        const currentObj = new index_js_1.StringObject("{");
        currentObj.addEnd("}");
        let object;
        try {
            if ([enums_js_1.TranspilerCustoms.FFS, enums_js_1.TranspilerCustoms.FS].some(x => parsedObj.startsWith(x))) {
                object = parsedObj;
            }
            else {
                object = (0, index_js_1.parseStringObject)(parsedObj, currentObj);
            }
        }
        catch (e) {
            throw new error_js_1.TranspilerError(`${data.name}: Invalid Object Provided`);
        }
        const res = (0, transpilerHelpers_js_1.escapeResult)(`const ${(0, transpilerHelpers_js_1.escapeVars)(name)} =  ${typeof object === "string" ? object : object.solve()};`);
        currentScope.objects[name] = object;
        currentScope.variables.push(name);
        currentScope.update(res, data);
        return {
            code: "",
            scope,
        };
    },
};
//# sourceMappingURL=$createObject.js.map