"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$deleteObjectProperty = void 0;
const error_js_1 = require("../../../core/error.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$deleteObjectProperty = {
    name: "$deleteObjectProperty",
    brackets: true,
    optional: false,
    type: "function",
    fields: [
        {
            name: "name",
            type: "string",
            description: "The name of the object to delete the property from",
            required: true,
        },
        {
            name: "key",
            type: "string",
            description: "The key of the property to delete",
            required: true,
        },
    ],
    version: "7.0.0",
    description: "deletes the key in the object",
    default: ["void", "void",],
    returns: "void",
    example: `
        $createObject[object;{key:value}]
        $deleteObjectProperty[object;key]
        $getObjectProperty[object;key] // returns undefined
    `,
    code: (data, scope) => {
        const currentScope = scope[scope.length - 1];
        const [name, key] = data.splits;
        if (!key.length &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name}: No Key Provided`);
        }
        if (!currentScope.objects[name] &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name}: Invalid Object Name Provided`);
        }
        const o = currentScope.objects[name];
        const index = o.keys.indexOf(key);
        o.keys.splice(index, 1);
        o.values.splice(index, 1);
        const res = (0, transpilerHelpers_js_1.escapeResult)(`delete ${(0, transpilerHelpers_js_1.escapeVars)(name)}.${key}`);
        currentScope.update(res, data);
        return {
            code: res,
            scope,
        };
    },
};
//# sourceMappingURL=$deleteObjectProperty.js.map