"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$getObject = void 0;
const error_js_1 = require("../../../core/error.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$getObject = {
    name: "$getObject",
    brackets: true,
    optional: false,
    type: "getter",
    fields: [
        {
            name: "name",
            type: "string",
            description: "The name of the object to get",
            required: true,
        },
    ],
    version: "7.0.0",
    description: "returns the object",
    default: ["void"],
    returns: "object",
    example: `
        $createObject[object;{key:value}]
        $getObject[object] // returns {key:value}
    `,
    code: (data, scope) => {
        const currentScope = scope[scope.length - 1];
        const name = data.inside;
        if (!name &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.endsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name}: No Object Name Provided`);
        }
        if (!currentScope.objects[name ?? ""] &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.endsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name}: Invalid Object Name Provided`);
        }
        if (!currentScope.packages.includes("const UTIL = await import('util');")) {
            currentScope.packages += "const UTIL = await import('util');\n";
        }
        const res = (0, transpilerHelpers_js_1.escapeResult)(`UTIL.inspect(${(0, transpilerHelpers_js_1.escapeVars)(name)},{depth:null})`);
        currentScope.update(res, data);
        return {
            code: res,
            scope,
        };
    },
};
//# sourceMappingURL=$getObject.js.map