"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$getObjectKeys = void 0;
const error_js_1 = require("../../../core/error.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$getObjectKeys = {
    name: "$getObjectKeys",
    brackets: true,
    optional: false,
    type: "getter",
    fields: [
        {
            name: "name",
            type: "string",
            description: "The name of the object to get the keys from",
            required: true,
        }
    ],
    version: "7.0.0",
    description: "returns all the key in the object",
    default: ["void",],
    returns: "void",
    example: `
        $createObject[object;{key:value,key2:value2}]
        $getObjectKeys[object] // returns key, key2
    `,
    code: (data, scope) => {
        const currentScope = scope[scope.length - 1];
        const name = data.inside;
        if (!name &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name}: No name Provided`);
        }
        if (!currentScope.objects[name] &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name}: Invalid Object Name Provided`);
        }
        const res = (0, transpilerHelpers_js_1.escapeResult)(`Object.keys(${(0, transpilerHelpers_js_1.escapeVars)(name)}).join(", ")`);
        currentScope.update(res, data);
        return {
            code: res,
            scope,
        };
    },
};
//# sourceMappingURL=$getObjectKeys.js.map