"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$getObjectProperty = void 0;
const error_js_1 = require("../../../core/error.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$getObjectProperty = {
    name: "$getObjectProperty",
    brackets: true,
    optional: false,
    type: "getter",
    fields: [
        {
            name: "name",
            type: "string",
            description: "The name of the object to get the property from",
            required: true,
        },
        {
            name: "key",
            type: "string",
            description: "The key of the property to get",
            required: true,
        },
    ],
    version: "7.0.0",
    description: "gets the value of the key in the object",
    default: ["void", "void"],
    returns: "void",
    example: `
        $createObject[object;{key:value}]
        $getObjectProperty[object;key] // returns value
    `,
    code: (data, scope) => {
        const currentScope = scope[scope.length - 1];
        const [name, key] = data.splits;
        if (!currentScope.objects[name] &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.startsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name}: Invalid Object Name Provided`);
        }
        const res = (0, transpilerHelpers_js_1.escapeResult)(`${(0, transpilerHelpers_js_1.escapeVars)(name)}.${key}`);
        currentScope.update(res, data);
        return {
            code: res,
            scope,
        };
    },
};
//# sourceMappingURL=$getObjectProperty.js.map