"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.$objectExists = void 0;
const error_js_1 = require("../../../core/error.js");
const transpilerHelpers_js_1 = require("../../../util/transpilerHelpers.js");
exports.$objectExists = {
    name: "$objectExists",
    brackets: true,
    optional: false,
    type: "getter",
    fields: [
        {
            name: "name",
            type: "string",
            description: "The name of the object to check",
            required: true,
        },
    ],
    version: "7.0.0",
    description: "returns whether object exists or not",
    default: ["void"],
    returns: "object",
    example: `
        $createObject[object;{key:value}]
        $objectExists[object] // returns true

        $objectExists[object2] // returns false
    `,
    code: (data, scope) => {
        const currentScope = scope[scope.length - 1];
        const name = data.inside;
        if (!name &&
            !currentScope.name.startsWith("$try_") &&
            !currentScope.name.endsWith("$catch_")) {
            throw new error_js_1.TranspilerError(`${data.name}: No Object Name Provided`);
        }
        const res = (0, transpilerHelpers_js_1.escapeResult)(`${!!currentScope.objects[name ?? ""]}`);
        currentScope.update(res, data);
        return {
            code: res,
            scope,
        };
    },
};
//# sourceMappingURL=$objectExists.js.map