"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandManager = void 0;
const structures_1 = require("@akarui/structures");
const Command_js_1 = require("../structures/Command.js");
const promises_1 = __importStar(require("fs/promises"));
const index_js_1 = require("../index.js");
const path_1 = __importDefault(require("path"));
class CommandManager {
    basic = new structures_1.Group(Infinity);
    interaction = new structures_1.Group(Infinity);
    ready = new structures_1.Group(Infinity);
    debug = new structures_1.Group(Infinity);
    component = new structures_1.Group(Infinity);
    #client;
    constructor(client) {
        this.#client = client;
    }
    isValidType(type) {
        return ["basic", "interaction", "ready", "debug"].includes(type);
    }
    get types() {
        return ["basic", "interaction", "ready", "debug"];
    }
    static cmdTypes() {
        return ["basic", "interaction", "ready", "debug", "component"];
    }
    add(command) {
        if (!command.name)
            throw new Error("Command name is required");
        if (!command.type)
            throw new Error("Command type is required");
        if (!command.__path__)
            command.__path__ = "root";
        const cmd = new Command_js_1.Command(command, this.#client);
        if (this.isValidType(command.type) && command.type !== "component")
            this[command.type].set(this[command.type].size, cmd);
        else {
            if (command.type === "component")
                this.component.set(command.name, cmd);
            else {
                // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                //@ts-ignore
                throw new Error("Invalid command type provided", {
                    ...command,
                });
            }
        }
    }
    addMany(commands) {
        for (const command of commands)
            this.add(command);
    }
    async load({ path, usingAoi = false, }) {
        const chalk = (await import("chalk")).default;
        const boxen = (await import("boxen")).default;
        const stats = await promises_1.default.stat(path);
        const Commands = [];
        if (!usingAoi) {
            if (stats.isDirectory()) {
                const files = await promises_1.default.readdir(path);
                for (const file of files) {
                    const filePath = path + "/" + file;
                    const stats = await promises_1.default.stat(filePath);
                    if (stats.isDirectory())
                        await this.load({ path: filePath, usingAoi });
                    else if (stats.isFile() &&
                        file.endsWith(".js") &&
                        !file.endsWith(".template.js")) {
                        // importing on windows
                        let command;
                        try {
                            command = await this.loadFile(filePath);
                            if (Array.isArray(command.default)) {
                                this.addMany(command.default);
                            }
                            else
                                this.add(command.default);
                            Commands.push({
                                path: filePath.split("/").pop(),
                                loaded: true,
                            });
                        }
                        catch (e) {
                            /* empty */
                            Commands.push({
                                path: filePath.split("/").pop(),
                                loaded: false,
                                reason: e,
                            });
                        }
                    }
                }
            }
        }
        else {
            if (stats.isDirectory()) {
                const files = await promises_1.default.readdir(path);
                for (const file of files) {
                    const filePath = path + "/" + file;
                    const stats = await promises_1.default.stat(filePath);
                    if (stats.isDirectory())
                        await this.load({ path: filePath, usingAoi });
                    else if (stats.isFile() &&
                        file.endsWith(".aoi") &&
                        !file.endsWith(".template.aoi")) {
                        const command = await (0, promises_1.readFile)(filePath, "utf-8");
                        try {
                            const cmd = (0, index_js_1.Bundler)(command, this.#client).command;
                            cmd.__path__ = filePath;
                            this.add(cmd);
                            Commands.push({
                                path: filePath.split("/").pop(),
                                loaded: true,
                            });
                        }
                        catch (e) {
                            /* empty */
                            Commands.push({
                                path: filePath.split("/").pop(),
                                loaded: false,
                                reason: e,
                            });
                        }
                    }
                    // else if(stats.isFile() && file.endsWith(".aoi") && !file.endsWith(".template.aoi")) {
                    //     const command = await import(filePath);
                    //     this.add(command.default);
                    // }
                }
            }
        }
        const box = boxen(`${Commands.map((cmd) => {
            return `∷ ${chalk.cyanBright(cmd.loaded ? "Loaded" : "Failed")} ${chalk.greenBright(cmd.path)} ${chalk.redBright(cmd.loaded ? "" : cmd.reason)}`;
        }).join("\n")}
        `, {
            title: `∴ Loading ${chalk.blueBright(path)} ( ${chalk.yellowBright(Commands.length)} )`,
            borderStyle: "round",
            borderColor: "cyan",
            textAlignment: "left",
            backgroundColor: "black",
            width: 100,
            padding: 1,
            dimBorder: true,
            float: "center",
        });
        console.log(box);
    }
    async exec({ type, data, filter, }) {
        const cmd = this[type].filter((cmd) => filter(cmd));
        if (cmd.size) {
            for (const command of cmd.values()) {
                this.#client.managers.plugins.preCommand.forEach((plugin) => {
                    plugin.func({ command, data });
                });
                await command.__compiled__({ ...data, command });
                this.#client.managers.plugins.postCommand.forEach((plugin) => {
                    plugin.func({ command, data });
                });
            }
        }
    }
    async loadFile(filePath) {
        let command;
        try {
            command = require(filePath);
        }
        catch {
            if (process.platform === "win32") {
                const fp = path_1.default.join("file:///", process.cwd(), filePath);
                command = await import(fp);
            }
            else {
                command = await import(path_1.default.join(process.cwd(), filePath));
            }
        }
        return command;
    }
}
exports.CommandManager = CommandManager;
//# sourceMappingURL=Command.js.map