"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
class PluginManager {
    constructor() {
        this.types = [
            "pre",
            "post",
            "load",
            "preEvent",
            "postEvent",
            "preCommand",
            "postCommand",
        ];
        this.#bindPlugins();
        this.#load();
    }
    #bindPlugins() {
        for (const type of this.types) {
            this[type] = [];
        }
    }
    add(plugin, type) {
        this[type].push(plugin);
    }
    getPlugins(type) {
        return this[type];
    }
    getPlugin(name, type) {
        return this[type].find((p) => p.name === name);
    }
    async #load() {
        if (!(0, fs_1.existsSync)("./aoijs.plugins.js"))
            return;
        const plugObj = (await import(path_1.default.join(process.cwd(), "./aoijs.plugins.js"))).default;
        for (const type of this.types) {
            if (!plugObj[type])
                continue;
            for (const plugin of plugObj[type]) {
                this.add(plugin, type);
            }
        }
    }
}
exports.default = PluginManager;
//# sourceMappingURL=Plugin.js.map