"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AoiClient = void 0;
const zeneth_1 = require("zeneth");
const Command_js_1 = require("../manager/Command.js");
const messageCreate_js_1 = require("../events/messageCreate.js");
const Util_js_1 = require("./Util.js");
const Function_js_1 = require("../manager/Function.js");
const Plugin_js_1 = __importDefault(require("../manager/Plugin.js"));
class AoiClient {
    constructor(options) {
        this.client = new zeneth_1.Client(options);
        this.managers = {
            commands: new Command_js_1.CommandManager(this),
            functions: new Function_js_1.FunctionManager(this),
            plugins: new Plugin_js_1.default(),
        };
        this.options = options;
        if (options.caches)
            this.cache = (0, zeneth_1.createCacheManager)(options.caches, this.client);
        this.#bindEvents();
        this.#bindCommands();
        this.util = Util_js_1.Util;
        Util_js_1.Util.client = this;
        this.__on__ = {};
        const plugs = this.managers.plugins.getPlugins("load");
        for (const plug of plugs) {
            plug.func(this);
        }
    }
    #bindEvents() {
        for (const event of this.options.events)
            if (event === "MessageCreate")
                (0, messageCreate_js_1.onMessage)(this);
    }
    #bindCommands() {
        const cmdTypes = this.managers.commands.types;
        for (const type of cmdTypes) {
            const cmdType = `${type}Command`;
            const parsedType = cmdType === "basicCommand" ? "command" : cmdType;
            this[parsedType] = function (...cmd) {
                const Cmds = cmd.map((c) => {
                    return {
                        ...c,
                        type,
                    };
                });
                this.managers.commands.addMany(Cmds);
            };
        }
        this.componentCommand = function (...cmd) {
            const Cmds = cmd.map((c) => {
                return {
                    ...c,
                    type: "component",
                };
            });
            this.managers.commands.addMany(Cmds);
        };
    }
    emit(event, ...args) {
        if (this.__on__[event]) {
            for (const func of this.__on__[event] ?? []) {
                func(...args);
            }
        }
    }
    on(event, func) {
        if (!this.__on__[event])
            this.__on__[event] = [];
        this.__on__[event]?.push(func);
    }
    createApplicationCommand(globalOrGuldId, data) {
        if (globalOrGuldId === "global") {
            return this.client.createGlobalApplicationCommand(data);
        }
        return this.client.createGuildApplicationCommand(globalOrGuldId, data);
    }
}
exports.AoiClient = AoiClient;
//# sourceMappingURL=AoiClient.js.map