"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeMultiLineComments = exports.isBigInt = exports.removeMF = exports.removeF = exports.removeFF = exports.convertToBool = exports._parseString = exports.ExecuteData = exports.Reverse = exports.reverseArray = exports.getFunctionList = exports.functionFinderRegex = exports.getFunctionData = exports.hasFunction = exports.escapeFunctionResult = exports.removeSetFunc = exports.parseResult = exports.escapeMathResult = exports.escapeResult = exports.escapeVars = exports.parseData = exports.countBrackets = exports.areBracketsBalanced = void 0;
const error_js_1 = require("../core/error.js");
const index_js_1 = __importDefault(require("../functions/index.js"));
const enums_js_1 = require("../typings/enums.js");
const index_js_2 = require("../index.js");
function areBracketsBalanced(code) {
    const leftbracket = /\[/g;
    const rightbracket = /\]/g;
    const leftbracketCount = code.match(leftbracket)?.length ?? 0;
    const rightbracketCount = code.match(rightbracket)?.length ?? 0;
    return leftbracketCount === rightbracketCount;
}
exports.areBracketsBalanced = areBracketsBalanced;
function countBrackets(code) {
    const leftbracket = /\[/g;
    const rightbracket = /\]/g;
    const leftbracketCount = code.match(leftbracket)?.length ?? 0;
    const rightbracketCount = code.match(rightbracket)?.length ?? 0;
    return { leftbracketCount, rightbracketCount };
}
exports.countBrackets = countBrackets;
function parseData(text) {
    if (text === "")
        return text;
    else if (!isNaN(Number(text)) && Number.isSafeInteger(Number(text)))
        return Number(text);
    else if ((!isNaN(Number(text)) && !Number.isSafeInteger(text)) ||
        isBigInt(text))
        return BigInt(text.replace("n", ""));
    else if (text === "null")
        return null;
    else if (text === "undefined")
        return undefined;
    else if (text === "true" || text === "false")
        return text === "true";
    else {
        try {
            return JSON.parse(text);
        }
        catch {
            if (text.startsWith("{") && text.endsWith("}")) {
                const so = new index_js_2.StringObject("{");
                so.addEnd("}");
                let e;
                eval(`e = ${(0, index_js_2.parseStringObject)(text, so).solve()}`);
                return e;
            }
            else if (text.startsWith("[") && text.endsWith("]")) {
                const so = new index_js_2.StringObject("[");
                so.addEnd("]");
                let e;
                eval(`e = ${(0, index_js_2.parseStringObject)(text, so).solve()}`);
                return e;
            }
            else
                return text;
        }
    }
}
exports.parseData = parseData;
function escapeVars(name) {
    return `__$${name}$__`;
}
exports.escapeVars = escapeVars;
function escapeResult(res) {
    return `${enums_js_1.TranspilerCustoms.FS}${res}${enums_js_1.TranspilerCustoms.FE}`;
}
exports.escapeResult = escapeResult;
function escapeMathResult(res) {
    return `${enums_js_1.TranspilerCustoms.MFS}${res}${enums_js_1.TranspilerCustoms.MFE}`;
}
exports.escapeMathResult = escapeMathResult;
function parseResult(result) {
    if (typeof result !== "string")
        return result;
    return result
        .replaceAll(enums_js_1.TranspilerCustoms.FS, "")
        .replaceAll(enums_js_1.TranspilerCustoms.FE, "")
        .replaceAll(enums_js_1.TranspilerCustoms.FSEP, ";")
        .replaceAll(enums_js_1.TranspilerCustoms.FFUN, "")
        .replaceAll(enums_js_1.TranspilerCustoms.FSET, "")
        .replaceAll(enums_js_1.TranspilerCustoms.FGET, "")
        .replaceAll(enums_js_1.TranspilerCustoms.FISS, "")
        .replaceAll(enums_js_1.TranspilerCustoms.FISE, "")
        .replaceAll(enums_js_1.TranspilerCustoms.FSS, "")
        .replaceAll(enums_js_1.TranspilerCustoms.FSE, "")
        .replaceAll(enums_js_1.TranspilerCustoms.FFS, "")
        .replaceAll(enums_js_1.TranspilerCustoms.FFE, "")
        .replaceAll(enums_js_1.TranspilerCustoms.MFS, "")
        .replaceAll(enums_js_1.TranspilerCustoms.MFE, "");
}
exports.parseResult = parseResult;
function removeSetFunc(code) {
    return code
        .replaceAll(enums_js_1.TranspilerCustoms.FSET, "")
        .replaceAll(enums_js_1.TranspilerCustoms.FFUN, "");
}
exports.removeSetFunc = removeSetFunc;
function escapeFunctionResult(result) {
    return `${enums_js_1.TranspilerCustoms.FFS}${enums_js_1.TranspilerCustoms.FS}${result}${enums_js_1.TranspilerCustoms.FE}${enums_js_1.TranspilerCustoms.FFE}`;
}
exports.escapeFunctionResult = escapeFunctionResult;
function hasFunction(code) {
    return exports.functionFinderRegex.test(code);
}
exports.hasFunction = hasFunction;
function getFunctionData(code, func, functions) {
    const FuncD = index_js_1.default[func];
    const reg = new RegExp(`${func.replace("$", "\\$")}`, "i");
    code = code.replace(reg, func);
    code = code.replaceAll("`", enums_js_1.TranspilerCustoms.SL);
    const functionPosition = code.indexOf(func);
    code = code.substring(functionPosition, code.length);
    let leftCount = 0, rightCount = 0, i = 0;
    let rawTotal = "";
    // eslint-disable-next-line no-constant-condition
    while (true) {
        if (!FuncD?.brackets && !code.slice(func.length).startsWith("[")) {
            break;
        }
        if (!FuncD?.optional && !code.slice(func.length).startsWith("[")) {
            throw new error_js_1.TranspilerError(`${func}: Required Brackets`);
        }
        if (areBracketsBalanced(code) &&
            countBrackets(code).leftbracketCount === 0)
            break;
        if (rightCount === leftCount && rightCount !== 0)
            break;
        if (!areBracketsBalanced(code)) {
            throw new error_js_1.TranspilerError("Brackets are not balanced in code:\n\n" + code);
        }
        if (code.slice(func.length)[0] !== "[") {
            break;
        }
        if (code[i] === "[")
            leftCount++;
        else if (code[i] === "]")
            rightCount++;
        rawTotal += code[i];
        i++;
    }
    if (rawTotal === "")
        rawTotal = func;
    const funcs = [];
    let inside = rawTotal.endsWith("]") && rawTotal.startsWith(`${func}[`)
        ? rawTotal.substring(func.length + 1, rawTotal.length - 1)
        : undefined;
    const list = getFunctionList(inside || "", functions);
    functions.splice(0, list.length);
    let newinside = inside || "";
    while (list.length) {
        const func = list.shift() || "";
        const funcData = getFunctionData(newinside, func, list);
        inside = inside?.replace(funcData.inside?.replaceAll(enums_js_1.TranspilerCustoms.FSEP, ";") ?? "", funcData.parsed);
        newinside = newinside.replace(funcData.total, enums_js_1.TranspilerCustoms.F);
        funcs.push(funcData);
    }
    const splits = inside?.split(";") || [];
    const parsed = inside?.replaceAll(";", enums_js_1.TranspilerCustoms.FSEP);
    return {
        inside,
        total: rawTotal,
        splits,
        funcs,
        parsed: parsed ?? "",
        ...FuncD,
    };
}
exports.getFunctionData = getFunctionData;
exports.functionFinderRegex = /(\$[a-z]+)/gi;
function getFunctionList(code, functions) {
    const raws = code.match(exports.functionFinderRegex);
    if (!raws)
        return [];
    const functionsThatExists = functions.filter((x) => code.toLowerCase().includes(x.toLowerCase()));
    const res = [];
    for (const raw of raws) {
        const func = functionsThatExists.filter((x) => x.toLowerCase() === raw.toLowerCase().slice(0, x.length));
        if (func.length === 1)
            res.push(func[0]);
        else if (func.length > 1) {
            res.push(func.sort((a, b) => b.length - a.length)[0]);
        }
        else {
            continue;
        }
    }
    return res;
}
exports.getFunctionList = getFunctionList;
function reverseArray(arr) {
    const res = [];
    for (let i = arr.length - 1; i >= 0; i--) {
        const el = arr[i];
        if (el.funcs.length)
            el.funcs = reverseArray(arr[i].funcs);
        res.push(el);
    }
    return res;
}
exports.reverseArray = reverseArray;
function Reverse(code, funcs) {
    let codeWithGenricFuncs = code;
    for (const func of funcs) {
        codeWithGenricFuncs = codeWithGenricFuncs.replace(func.total, "#GENERIC-FUNCTION#");
    }
    const reversedFuncs = reverseArray(funcs);
    for (const func of reversedFuncs) {
        codeWithGenricFuncs = codeWithGenricFuncs.replace("#GENERIC-FUNCTION#", func.total);
    }
    return { code: codeWithGenricFuncs, funcs: reversedFuncs };
}
exports.Reverse = Reverse;
function ExecuteData(code, data, scope, reverse = false) {
    let i = 0;
    if (reverse) {
        const { code: newCode, funcs } = Reverse(code, data);
        code = newCode;
        data = funcs;
        scope[0].rest = code;
    }
    while (i < data.length) {
        let d = data[i];
        const oldd = data[i].total;
        if (d.type === "scope" || d.type === "scope_getter") {
            const result = d.code(d, scope);
            scope = result.scope;
            d = result.data;
            code = code.replace(d.total, result.code.replaceAll("$", "$$$$"));
            // .replace(d.total.replaceAll(";", "#FUNCTION_SEPARATOR#"), result.code);
            if (d.type === "scope_getter") {
                d.total = removeFF(d.total);
                scope[scope.length - 1].sendData.content = scope[scope.length - 1].sendData.content.replace(d.total, result.code.replaceAll("$", "$$$$"));
            }
        }
        else {
            let executed;
            if (d.funcs.length) {
                executed = ExecuteData(parseResult(d.inside ?? ""), d.funcs, scope);
                scope = executed.scope;
                const oldtotal = d.total;
                d.total = d.total
                    .replace(d.inside ?? "", executed.code.replaceAll("$", "$$$$"))
                    .replace(d.inside?.replaceAll(enums_js_1.TranspilerCustoms.FSEP, ";") ?? "", executed.code.replaceAll("$", "$$$$"));
                code = code
                    .replace(oldtotal, d.total.replaceAll("$", "$$$$"))
                    .replace(oldd, d.total.replaceAll("$", "$$$$"));
                d.inside = executed.code;
                d.splits = d.inside.split(";");
                const result = d.code(d, scope);
                code = code
                    .replace(d.total, result.code.replaceAll("$", "$$$$"))
                    // .replace(d.total.replaceAll(";", "#FUNCTION_SEPARATOR#"), result.code)
                    .replace(oldd, result.code.replaceAll("$", "$$$$"));
                if (d.type === "getter" || d.type === "function_getter") {
                    let oldcontent = scope[scope.length - 1].sendData.content;
                    scope[scope.length - 1].sendData.content = scope[scope.length - 1].sendData.content.replace(d.total, result.code.replaceAll("$", "$$$$"));
                    if (oldcontent === scope[scope.length - 1].sendData.content) {
                        scope[scope.length - 1].sendData.content = scope[scope.length - 1].sendData.content.replace(d.total.replaceAll(";", enums_js_1.TranspilerCustoms.FSEP), result.code.replaceAll("$", "$$$$"));
                        oldcontent = scope[scope.length - 1].sendData.content;
                    }
                    if (oldcontent === scope[scope.length - 1].sendData.content)
                        scope[scope.length - 1].sendData.content = scope[scope.length - 1].sendData.content.replace(oldd, result.code.replaceAll("$", "$$$$"));
                }
            }
            else {
                executed = d.code(d, scope);
                scope = executed.scope;
                code = code.replace(d.total, executed.code.replaceAll("$", "$$$$"));
                if (d.type === "getter" || d.type === "function_getter") {
                    const oldt = d.total;
                    const oldcontent = scope[scope.length - 1].sendData.content;
                    d.total = removeFF(d.total);
                    scope[scope.length - 1].sendData.content = scope[scope.length - 1].sendData.content.replace(d.total, executed.code.replaceAll("$", "$$$$"));
                    if (oldcontent === scope[scope.length - 1].sendData.content)
                        scope[scope.length - 1].sendData.content = scope[scope.length - 1].sendData.content.replace(oldt, executed.code.replaceAll("$", "$$$$"));
                }
            }
        }
        if (d.type !== "getter" &&
            d.type !== "function_getter" &&
            d.type !== "scope_getter") {
            const s = scope[scope.length - 1];
            const oldt = d.total;
            const oldcontent = s.sendData.content;
            d.total = removeFF(d.total);
            s.sendData.content = s.sendData.content.replace(d.total, "");
            if (oldcontent === s.sendData.content)
                s.sendData.content = s.sendData.content.replace(oldt, "");
            scope[scope.length - 1] = s;
        }
        i++;
    }
    return {
        code,
        scope,
    };
}
exports.ExecuteData = ExecuteData;
function _parseString(text) {
    const reg = /((#FUNCTION_START#([\s$a-z.0-9?(){}[\]._:'"`;=><,!-]|\n)+#FUNCTION_END#)|(__\$[a-z_?.()]+\$__))/gim;
    let matches = text.match(reg);
    const functionlist = matches?.slice(1) ?? [];
    functionlist;
    let temptext = text;
    if (matches) {
        matches = matches.reverse();
        let i = 0;
        let u = 0;
        while (i < (matches?.length ?? 0)) {
            const match = matches?.[i];
            const position = temptext.indexOf(match);
            const part = temptext.slice(position, position + match.length);
            const temppart = parseResult(part);
            temptext = `${temptext.slice(0, position)}${`__$${u
                .toString()
                .repeat(temppart.length - 3)}$__`}${temptext.slice(position + part.length, text.length)}`;
            text = `${text.slice(0, position)}\${${temppart}}${text.slice(position + part.length, text.length)}`;
            matches = (temptext.match(reg)?.reverse() ?? []);
            i = 0;
            u++;
        }
        matches = ((text.match(/__\$[0-9]+\$__/gi)?.reverse() ?? []));
        matches?.forEach((x, y) => {
            text = text.replace(x, `\${${parseResult(functionlist[y])}}`);
        });
        text = `\`${text}\``;
    }
    else {
        text = `\`${text}\``;
    }
    return text;
}
exports._parseString = _parseString;
function convertToBool(output) {
    return output === "true" || output === "yes" ? true : false;
}
exports.convertToBool = convertToBool;
function removeFF(total) {
    if (!total.includes(enums_js_1.TranspilerCustoms.FFS))
        return total;
    const parts = total.split(enums_js_1.TranspilerCustoms.FFS).slice(1);
    let i = 0;
    while (i < parts.length) {
        const part = parts[i].split(enums_js_1.TranspilerCustoms.FFE)[0];
        total = total.replace(part, "");
        i++;
    }
    return parseResult(total);
}
exports.removeFF = removeFF;
function removeF(total) {
    if (!total.includes(enums_js_1.TranspilerCustoms.FS))
        return total;
    const parts = total.split(enums_js_1.TranspilerCustoms.FS).slice(1);
    let i = 0;
    while (i < parts.length) {
        const part = parts[i].split(enums_js_1.TranspilerCustoms.FE)[0];
        total = total.replace(part, "");
        i++;
    }
    return total;
}
exports.removeF = removeF;
function removeMF(total) {
    if (!total.includes(enums_js_1.TranspilerCustoms.MFS))
        return total;
    const parts = total.split(enums_js_1.TranspilerCustoms.MFS).slice(1);
    let i = 0;
    while (i < parts.length) {
        const part = parts[i].split(enums_js_1.TranspilerCustoms.MFE)[0];
        total = total.replace(part, "");
        i++;
    }
    return total;
}
exports.removeMF = removeMF;
function isBigInt(string) {
    return string.match(/^-?\d+n$/) !== null;
}
exports.isBigInt = isBigInt;
function removeMultiLineComments(code) {
    return code.replace(/\/\*[\s\S]*?\*\//g, "");
}
exports.removeMultiLineComments = removeMultiLineComments;
//# sourceMappingURL=transpilerHelpers.js.map