import { existsSync } from "fs";
import path from "path";
class PluginManager {
    constructor() {
        this.types = [
            "pre",
            "post",
            "load",
            "preEvent",
            "postEvent",
            "preCommand",
            "postCommand",
        ];
        this.#bindPlugins();
        this.#load();
    }
    #bindPlugins() {
        for (const type of this.types) {
            this[type] = [];
        }
    }
    add(plugin, type) {
        this[type].push(plugin);
    }
    getPlugins(type) {
        return this[type];
    }
    getPlugin(name, type) {
        return this[type].find((p) => p.name === name);
    }
    async #load() {
        if (!existsSync("./aoijs.plugins.js"))
            return;
        const plugObj = (await import(path.join(process.cwd(), "./aoijs.plugins.js"))).default;
        for (const type of this.types) {
            if (!plugObj[type])
                continue;
            for (const plugin of plugObj[type]) {
                this.add(plugin, type);
            }
        }
    }
}
export default PluginManager;
//# sourceMappingURL=Plugin.js.map