import { Client, createCacheManager, } from "zeneth";
import { CommandManager } from "../manager/Command.js";
import { onMessage } from "../events/messageCreate.js";
import { Util } from "./Util.js";
import { FunctionManager } from "../manager/Function.js";
import PluginManager from "../manager/Plugin.js";
class AoiClient {
    constructor(options) {
        this.client = new Client(options);
        this.managers = {
            commands: new CommandManager(this),
            functions: new FunctionManager(this),
            plugins: new PluginManager(),
        };
        this.options = options;
        if (options.caches)
            this.cache = createCacheManager(options.caches, this.client);
        this.#bindEvents();
        this.#bindCommands();
        this.util = Util;
        Util.client = this;
        this.__on__ = {};
        const plugs = this.managers.plugins.getPlugins("load");
        for (const plug of plugs) {
            plug.func(this);
        }
    }
    #bindEvents() {
        for (const event of this.options.events)
            if (event === "MessageCreate")
                onMessage(this);
    }
    #bindCommands() {
        const cmdTypes = this.managers.commands.types;
        for (const type of cmdTypes) {
            const cmdType = `${type}Command`;
            const parsedType = cmdType === "basicCommand" ? "command" : cmdType;
            this[parsedType] = function (...cmd) {
                const Cmds = cmd.map((c) => {
                    return {
                        ...c,
                        type,
                    };
                });
                this.managers.commands.addMany(Cmds);
            };
        }
        this.componentCommand = function (...cmd) {
            const Cmds = cmd.map((c) => {
                return {
                    ...c,
                    type: "component",
                };
            });
            this.managers.commands.addMany(Cmds);
        };
    }
    emit(event, ...args) {
        if (this.__on__[event]) {
            for (const func of this.__on__[event] ?? []) {
                func(...args);
            }
        }
    }
    on(event, func) {
        if (!this.__on__[event])
            this.__on__[event] = [];
        this.__on__[event]?.push(func);
    }
    createApplicationCommand(globalOrGuldId, data) {
        if (globalOrGuldId === "global") {
            return this.client.createGlobalApplicationCommand(data);
        }
        return this.client.createGuildApplicationCommand(globalOrGuldId, data);
    }
}
export { AoiClient };
//# sourceMappingURL=AoiClient.js.map