import { TranspilerError } from "../core/error.js";
import FUNCDATA from "../functions/index.js";
import { TranspilerCustoms } from "../typings/enums.js";
import { StringObject, parseStringObject } from "../index.js";
export function areBracketsBalanced(code) {
    const leftbracket = /\[/g;
    const rightbracket = /\]/g;
    const leftbracketCount = code.match(leftbracket)?.length ?? 0;
    const rightbracketCount = code.match(rightbracket)?.length ?? 0;
    return leftbracketCount === rightbracketCount;
}
export function countBrackets(code) {
    const leftbracket = /\[/g;
    const rightbracket = /\]/g;
    const leftbracketCount = code.match(leftbracket)?.length ?? 0;
    const rightbracketCount = code.match(rightbracket)?.length ?? 0;
    return { leftbracketCount, rightbracketCount };
}
export function parseData(text) {
    if (text === "")
        return text;
    else if (!isNaN(Number(text)) && Number.isSafeInteger(Number(text)))
        return Number(text);
    else if ((!isNaN(Number(text)) && !Number.isSafeInteger(text)) ||
        isBigInt(text))
        return BigInt(text.replace("n", ""));
    else if (text === "null")
        return null;
    else if (text === "undefined")
        return undefined;
    else if (text === "true" || text === "false")
        return text === "true";
    else {
        try {
            return JSON.parse(text);
        }
        catch {
            if (text.startsWith("{") && text.endsWith("}")) {
                const so = new StringObject("{");
                so.addEnd("}");
                let e;
                eval(`e = ${parseStringObject(text, so).solve()}`);
                return e;
            }
            else if (text.startsWith("[") && text.endsWith("]")) {
                const so = new StringObject("[");
                so.addEnd("]");
                let e;
                eval(`e = ${parseStringObject(text, so).solve()}`);
                return e;
            }
            else
                return text;
        }
    }
}
export function escapeVars(name) {
    return `__$${name}$__`;
}
export function escapeResult(res) {
    return `${TranspilerCustoms.FS}${res}${TranspilerCustoms.FE}`;
}
export function escapeMathResult(res) {
    return `${TranspilerCustoms.MFS}${res}${TranspilerCustoms.MFE}`;
}
export function parseResult(result) {
    if (typeof result !== "string")
        return result;
    return result
        .replaceAll(TranspilerCustoms.FS, "")
        .replaceAll(TranspilerCustoms.FE, "")
        .replaceAll(TranspilerCustoms.FSEP, ";")
        .replaceAll(TranspilerCustoms.FFUN, "")
        .replaceAll(TranspilerCustoms.FSET, "")
        .replaceAll(TranspilerCustoms.FGET, "")
        .replaceAll(TranspilerCustoms.FISS, "")
        .replaceAll(TranspilerCustoms.FISE, "")
        .replaceAll(TranspilerCustoms.FSS, "")
        .replaceAll(TranspilerCustoms.FSE, "")
        .replaceAll(TranspilerCustoms.FFS, "")
        .replaceAll(TranspilerCustoms.FFE, "")
        .replaceAll(TranspilerCustoms.MFS, "")
        .replaceAll(TranspilerCustoms.MFE, "");
}
export function removeSetFunc(code) {
    return code
        .replaceAll(TranspilerCustoms.FSET, "")
        .replaceAll(TranspilerCustoms.FFUN, "");
}
export function escapeFunctionResult(result) {
    return `${TranspilerCustoms.FFS}${TranspilerCustoms.FS}${result}${TranspilerCustoms.FE}${TranspilerCustoms.FFE}`;
}
export function hasFunction(code) {
    return functionFinderRegex.test(code);
}
export function getFunctionData(code, func, functions) {
    const FuncD = FUNCDATA[func];
    const reg = new RegExp(`${func.replace("$", "\\$")}`, "i");
    code = code.replace(reg, func);
    code = code.replaceAll("`", TranspilerCustoms.SL);
    const functionPosition = code.indexOf(func);
    code = code.substring(functionPosition, code.length);
    let leftCount = 0, rightCount = 0, i = 0;
    let rawTotal = "";
    // eslint-disable-next-line no-constant-condition
    while (true) {
        if (!FuncD?.brackets && !code.slice(func.length).startsWith("[")) {
            break;
        }
        if (!FuncD?.optional && !code.slice(func.length).startsWith("[")) {
            throw new TranspilerError(`${func}: Required Brackets`);
        }
        if (areBracketsBalanced(code) &&
            countBrackets(code).leftbracketCount === 0)
            break;
        if (rightCount === leftCount && rightCount !== 0)
            break;
        if (!areBracketsBalanced(code)) {
            throw new TranspilerError("Brackets are not balanced in code:\n\n" + code);
        }
        if (code.slice(func.length)[0] !== "[") {
            break;
        }
        if (code[i] === "[")
            leftCount++;
        else if (code[i] === "]")
            rightCount++;
        rawTotal += code[i];
        i++;
    }
    if (rawTotal === "")
        rawTotal = func;
    const funcs = [];
    let inside = rawTotal.endsWith("]") && rawTotal.startsWith(`${func}[`)
        ? rawTotal.substring(func.length + 1, rawTotal.length - 1)
        : undefined;
    const list = getFunctionList(inside || "", functions);
    functions.splice(0, list.length);
    let newinside = inside || "";
    while (list.length) {
        const func = list.shift() || "";
        const funcData = getFunctionData(newinside, func, list);
        inside = inside?.replace(funcData.inside?.replaceAll(TranspilerCustoms.FSEP, ";") ?? "", funcData.parsed);
        newinside = newinside.replace(funcData.total, TranspilerCustoms.F);
        funcs.push(funcData);
    }
    const splits = inside?.split(";") || [];
    const parsed = inside?.replaceAll(";", TranspilerCustoms.FSEP);
    return {
        inside,
        total: rawTotal,
        splits,
        funcs,
        parsed: parsed ?? "",
        ...FuncD,
    };
}
export const functionFinderRegex = /(\$[a-z]+)/gi;
export function getFunctionList(code, functions) {
    const raws = code.match(functionFinderRegex);
    if (!raws)
        return [];
    const functionsThatExists = functions.filter((x) => code.toLowerCase().includes(x.toLowerCase()));
    const res = [];
    for (const raw of raws) {
        const func = functionsThatExists.filter((x) => x.toLowerCase() === raw.toLowerCase().slice(0, x.length));
        if (func.length === 1)
            res.push(func[0]);
        else if (func.length > 1) {
            res.push(func.sort((a, b) => b.length - a.length)[0]);
        }
        else {
            continue;
        }
    }
    return res;
}
export function reverseArray(arr) {
    const res = [];
    for (let i = arr.length - 1; i >= 0; i--) {
        const el = arr[i];
        if (el.funcs.length)
            el.funcs = reverseArray(arr[i].funcs);
        res.push(el);
    }
    return res;
}
export function Reverse(code, funcs) {
    let codeWithGenricFuncs = code;
    for (const func of funcs) {
        codeWithGenricFuncs = codeWithGenricFuncs.replace(func.total, "#GENERIC-FUNCTION#");
    }
    const reversedFuncs = reverseArray(funcs);
    for (const func of reversedFuncs) {
        codeWithGenricFuncs = codeWithGenricFuncs.replace("#GENERIC-FUNCTION#", func.total);
    }
    return { code: codeWithGenricFuncs, funcs: reversedFuncs };
}
export function ExecuteData(code, data, scope, reverse = false) {
    let i = 0;
    if (reverse) {
        const { code: newCode, funcs } = Reverse(code, data);
        code = newCode;
        data = funcs;
        scope[0].rest = code;
    }
    while (i < data.length) {
        let d = data[i];
        const oldd = data[i].total;
        if (d.type === "scope" || d.type === "scope_getter") {
            const result = d.code(d, scope);
            scope = result.scope;
            d = result.data;
            code = code.replace(d.total, result.code.replaceAll("$", "$$$$"));
            // .replace(d.total.replaceAll(";", "#FUNCTION_SEPARATOR#"), result.code);
            if (d.type === "scope_getter") {
                d.total = removeFF(d.total);
                scope[scope.length - 1].sendData.content = scope[scope.length - 1].sendData.content.replace(d.total, result.code.replaceAll("$", "$$$$"));
            }
        }
        else {
            let executed;
            if (d.funcs.length) {
                executed = ExecuteData(parseResult(d.inside ?? ""), d.funcs, scope);
                scope = executed.scope;
                const oldtotal = d.total;
                d.total = d.total
                    .replace(d.inside ?? "", executed.code.replaceAll("$", "$$$$"))
                    .replace(d.inside?.replaceAll(TranspilerCustoms.FSEP, ";") ?? "", executed.code.replaceAll("$", "$$$$"));
                code = code
                    .replace(oldtotal, d.total.replaceAll("$", "$$$$"))
                    .replace(oldd, d.total.replaceAll("$", "$$$$"));
                d.inside = executed.code;
                d.splits = d.inside.split(";");
                const result = d.code(d, scope);
                code = code
                    .replace(d.total, result.code.replaceAll("$", "$$$$"))
                    // .replace(d.total.replaceAll(";", "#FUNCTION_SEPARATOR#"), result.code)
                    .replace(oldd, result.code.replaceAll("$", "$$$$"));
                if (d.type === "getter" || d.type === "function_getter") {
                    let oldcontent = scope[scope.length - 1].sendData.content;
                    scope[scope.length - 1].sendData.content = scope[scope.length - 1].sendData.content.replace(d.total, result.code.replaceAll("$", "$$$$"));
                    if (oldcontent === scope[scope.length - 1].sendData.content) {
                        scope[scope.length - 1].sendData.content = scope[scope.length - 1].sendData.content.replace(d.total.replaceAll(";", TranspilerCustoms.FSEP), result.code.replaceAll("$", "$$$$"));
                        oldcontent = scope[scope.length - 1].sendData.content;
                    }
                    if (oldcontent === scope[scope.length - 1].sendData.content)
                        scope[scope.length - 1].sendData.content = scope[scope.length - 1].sendData.content.replace(oldd, result.code.replaceAll("$", "$$$$"));
                }
            }
            else {
                executed = d.code(d, scope);
                scope = executed.scope;
                code = code.replace(d.total, executed.code.replaceAll("$", "$$$$"));
                if (d.type === "getter" || d.type === "function_getter") {
                    const oldt = d.total;
                    const oldcontent = scope[scope.length - 1].sendData.content;
                    d.total = removeFF(d.total);
                    scope[scope.length - 1].sendData.content = scope[scope.length - 1].sendData.content.replace(d.total, executed.code.replaceAll("$", "$$$$"));
                    if (oldcontent === scope[scope.length - 1].sendData.content)
                        scope[scope.length - 1].sendData.content = scope[scope.length - 1].sendData.content.replace(oldt, executed.code.replaceAll("$", "$$$$"));
                }
            }
        }
        if (d.type !== "getter" &&
            d.type !== "function_getter" &&
            d.type !== "scope_getter") {
            const s = scope[scope.length - 1];
            const oldt = d.total;
            const oldcontent = s.sendData.content;
            d.total = removeFF(d.total);
            s.sendData.content = s.sendData.content.replace(d.total, "");
            if (oldcontent === s.sendData.content)
                s.sendData.content = s.sendData.content.replace(oldt, "");
            scope[scope.length - 1] = s;
        }
        i++;
    }
    return {
        code,
        scope,
    };
}
export function _parseString(text) {
    const reg = /((#FUNCTION_START#([\s$a-z.0-9?(){}[\]._:'"`;=><,!-]|\n)+#FUNCTION_END#)|(__\$[a-z_?.()]+\$__))/gim;
    let matches = text.match(reg);
    const functionlist = matches?.slice(1) ?? [];
    functionlist;
    let temptext = text;
    if (matches) {
        matches = matches.reverse();
        let i = 0;
        let u = 0;
        while (i < (matches?.length ?? 0)) {
            const match = matches?.[i];
            const position = temptext.indexOf(match);
            const part = temptext.slice(position, position + match.length);
            const temppart = parseResult(part);
            temptext = `${temptext.slice(0, position)}${`__$${u
                .toString()
                .repeat(temppart.length - 3)}$__`}${temptext.slice(position + part.length, text.length)}`;
            text = `${text.slice(0, position)}\${${temppart}}${text.slice(position + part.length, text.length)}`;
            matches = (temptext.match(reg)?.reverse() ?? []);
            i = 0;
            u++;
        }
        matches = ((text.match(/__\$[0-9]+\$__/gi)?.reverse() ?? []));
        matches?.forEach((x, y) => {
            text = text.replace(x, `\${${parseResult(functionlist[y])}}`);
        });
        text = `\`${text}\``;
    }
    else {
        text = `\`${text}\``;
    }
    return text;
}
export function convertToBool(output) {
    return output === "true" || output === "yes" ? true : false;
}
export function removeFF(total) {
    if (!total.includes(TranspilerCustoms.FFS))
        return total;
    const parts = total.split(TranspilerCustoms.FFS).slice(1);
    let i = 0;
    while (i < parts.length) {
        const part = parts[i].split(TranspilerCustoms.FFE)[0];
        total = total.replace(part, "");
        i++;
    }
    return parseResult(total);
}
export function removeF(total) {
    if (!total.includes(TranspilerCustoms.FS))
        return total;
    const parts = total.split(TranspilerCustoms.FS).slice(1);
    let i = 0;
    while (i < parts.length) {
        const part = parts[i].split(TranspilerCustoms.FE)[0];
        total = total.replace(part, "");
        i++;
    }
    return total;
}
export function removeMF(total) {
    if (!total.includes(TranspilerCustoms.MFS))
        return total;
    const parts = total.split(TranspilerCustoms.MFS).slice(1);
    let i = 0;
    while (i < parts.length) {
        const part = parts[i].split(TranspilerCustoms.MFE)[0];
        total = total.replace(part, "");
        i++;
    }
    return total;
}
export function isBigInt(string) {
    return string.match(/^-?\d+n$/) !== null;
}
export function removeMultiLineComments(code) {
    return code.replace(/\/\*[\s\S]*?\*\//g, "");
}
//# sourceMappingURL=transpilerHelpers.js.map